"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QNetworkCookieJar(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qnetworkcookiejar.html

    **Detailed Description**

    Cookies are small bits of information that stateless protocols like HTTP use
    to maintain some persistent information across requests.

    A cookie is set by a remote server when it replies to a request and it
    expects the same cookie to be sent back when further requests are sent.

    The cookie jar is the object that holds all cookies set in previous
    requests. Web browsers save their cookie jars to disk in order to conserve
    permanent cookies across invocations of the application.

    QNetworkCookieJar does not implement permanent storage: it only keeps the
    cookies in memory. Once the QNetworkCookieJar object is deleted, all cookies
    it held will be discarded as well. If you want to save the cookies, you
    should derive from this class and implement the saving to disk to your own
    storage format.

    This class implements only the basic security recommended by the cookie
    specifications and does not implement any cookie acceptance policy (it
    accepts all cookies set by any requests). In order to override those rules,
    you should reimplement the **cookiesForUrl** () and **setCookiesFromUrl** ()
    virtual functions. They are called by **QNetworkReply**  and
    **QNetworkAccessManager**  when they detect new cookies and when they
    require cookies.

    **See also** **QNetworkCookie** , **QNetworkAccessManager** ,
    **QNetworkReply** , **QNetworkRequest** , and
    **QNetworkAccessManager::setCookieJar** ().
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#QNetworkCookieJar

        **QNetworkCookieJar::QNetworkCookieJar(QObject * parent = nullptr)**

        Creates a QNetworkCookieJar object and sets the parent object to be
        **parent**.

        The cookie jar is initialized to empty.
        """
        ...

    def validateCookie(self, cookie: QNetworkCookie, url: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#validateCookie

        **[virtual protected, since 5.0] bool
        QNetworkCookieJar::validateCookie(const QNetworkCookie & cookie , const
        QUrl & url ) const**

        Returns `true` if the domain and path of **cookie** are valid, false
        otherwise. The **url** parameter is used to determine if the domain
        specified in the cookie is allowed.

        This function was introduced in Qt 5.0.
        """
        ...

    def allCookies(self) -> typing.List[QNetworkCookie]:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#allCookies

        **[protected] QList<QNetworkCookie> QNetworkCookieJar::allCookies()
        const**

        Returns all cookies stored in this cookie jar. This function is suitable
        for derived classes to save cookies to disk, as well as to implement
        cookie expiration and other policies.

        **See also** **setAllCookies** () and **cookiesForUrl** ().
        """
        ...

    def setAllCookies(self, cookieList: typing.Iterable[QNetworkCookie]) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#setAllCookies

        **[protected] void QNetworkCookieJar::setAllCookies(const
        QList<QNetworkCookie> & cookieList )**

        Sets the internal list of cookies held by this cookie jar to be
        **cookieList**. This function is suitable for derived classes to
        implement loading cookies from permanent storage, or their own cookie
        acceptance policies by reimplementing **setCookiesFromUrl** ().

        **See also** **allCookies** () and **setCookiesFromUrl** ().
        """
        ...

    def deleteCookie(self, cookie: QNetworkCookie) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#deleteCookie

        **[virtual, since 5.0] bool QNetworkCookieJar::deleteCookie(const
        QNetworkCookie & cookie )**

        Deletes from cookie jar the cookie found to have the same identifier as
        **cookie**.

        Returns `true` if a cookie was deleted, false otherwise.

        This function was introduced in Qt 5.0.

        **See also** **QNetworkCookie::hasSameIdentifier** ().
        """
        ...

    def updateCookie(self, cookie: QNetworkCookie) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#updateCookie

        **[virtual, since 5.0] bool QNetworkCookieJar::updateCookie(const
        QNetworkCookie & cookie )**

        If a cookie with the same identifier as **cookie** exists in this cookie
        jar it will be updated. This function uses **insertCookie** ().

        Returns `true` if **cookie** was updated, false if no cookie in the jar
        matches the identifier of **cookie**.

        This function was introduced in Qt 5.0.

        **See also** **QNetworkCookie::hasSameIdentifier** ().
        """
        ...

    def insertCookie(self, cookie: QNetworkCookie) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#insertCookie

        **[virtual, since 5.0] bool QNetworkCookieJar::insertCookie(const
        QNetworkCookie & cookie )**

        Adds **cookie** to this cookie jar.

        Returns `true` if **cookie** was added, false otherwise.

        If a cookie with the same identifier already exists in the cookie jar,
        it will be overridden.

        This function was introduced in Qt 5.0.
        """
        ...

    def setCookiesFromUrl(
        self, cookieList: typing.Iterable[QNetworkCookie], url: QtCore.QUrl
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#setCookiesFromUrl

        **[virtual] bool QNetworkCookieJar::setCookiesFromUrl(const
        QList<QNetworkCookie> & cookieList , const QUrl & url )**

        Adds the cookies in the list **cookieList** to this cookie jar. Before
        being inserted cookies are normalized.

        Returns `true` if one or more cookies are set for **url** , otherwise
        false.

        If a cookie already exists in the cookie jar, it will be overridden by
        those in **cookieList**.

        The default **QNetworkCookieJar**  class implements only a very basic
        security policy (it makes sure that the cookies' domain and path match
        the reply's). To enhance the security policy with your own algorithms,
        override setCookiesFromUrl().

        Also, **QNetworkCookieJar**  does not have a maximum cookie jar size.
        Reimplement this function to discard older cookies to create room for
        new ones.

        **See also** **cookiesForUrl** (),
        **QNetworkAccessManager::setCookieJar** (), and
        **QNetworkCookie::normalize** ().
        """
        ...

    def cookiesForUrl(self, url: QtCore.QUrl) -> typing.List[QNetworkCookie]:
        """
        https://doc.qt.io/qt-6/qnetworkcookiejar.html#cookiesForUrl

        **[virtual] QList<QNetworkCookie> QNetworkCookieJar::cookiesForUrl(const
        QUrl & url ) const**

        Returns the cookies to be added to when a request is sent to **url**.
        This function is called by the default
        **QNetworkAccessManager::createRequest** (), which adds the cookies
        returned by this function to the request being sent.

        If more than one cookie with the same name is found, but with differing
        paths, the one with longer path is returned before the one with shorter
        path. In other words, this function returns cookies sorted decreasingly
        by path length.

        The default **QNetworkCookieJar**  class implements only a very basic
        security policy (it makes sure that the cookies' domain and path match
        the reply's). To enhance the security policy with your own algorithms,
        override cookiesForUrl().

        **See also** **setCookiesFromUrl** () and
        **QNetworkAccessManager::setCookieJar** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsPathItem(QAbstractGraphicsShapeItem):
    """
    https://doc.qt.io/qt-6/qgraphicspathitem.html

    **Detailed Description**

    To set the item's path, pass a **QPainterPath**  to QGraphicsPathItem's
    constructor, or call the **setPath** () function. The **path** () function
    returns the current path.

    ![](images/graphicsview-pathitem.png)

    QGraphicsPathItem uses the path to provide a reasonable implementation of
    **boundingRect** (), **shape** (), and **contains** (). The **paint** ()
    function draws the path using the item's associated pen and brush, which you
    can set by calling the **setPen** () and **setBrush** () functions.

    **See also** **QGraphicsRectItem** , **QGraphicsEllipseItem** ,
    **QGraphicsPolygonItem** , **QGraphicsTextItem** , **QGraphicsLineItem** ,
    **QGraphicsPixmapItem** , and **Graphics View Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#QGraphicsPathItem

        **QGraphicsPathItem::QGraphicsPathItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsPath. **parent** is passed to
        **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self, path: QtGui.QPainterPath, parent: typing.Optional[QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#QGraphicsPathItem-1

        **QGraphicsPathItem::QGraphicsPathItem(const QPainterPath & path ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsPath item using **path** as the default path.
        **parent** is passed to **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#type

        **[override virtual] int QGraphicsPathItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsPathItem::opaqueArea()
        const**

        Reimplements: **QAbstractGraphicsShapeItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#isObscuredBy

        **[override virtual] bool QGraphicsPathItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem *item) const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#paint

        **[override virtual] void QGraphicsPathItem::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#contains

        **[override virtual] bool QGraphicsPathItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#shape

        **[override virtual] QPainterPath QGraphicsPathItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#boundingRect

        **[override virtual] QRectF QGraphicsPathItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def setPath(self, path: QtGui.QPainterPath) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#setPath

        **void QGraphicsPathItem::setPath(const QPainterPath & path )**

        Sets the item's path to be the given **path**.

        **See also** **path** ().
        """
        ...

    def path(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspathitem.html#path

        **QPainterPath QGraphicsPathItem::path() const**

        Returns the item's path as a **QPainterPath** . If no item has been set,
        an empty **QPainterPath**  is returned.

        **See also** **setPath** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtOpenGL import *


class QOpenGLFramebufferObjectFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html

    **Detailed Description**

    A framebuffer object has several characteristics:

    * **Number of samples per pixels.**
      * **Depth and/or stencil
    attachments.**
      * **Texture target.**
      * **Internal texture format.**

    Note that the desired attachments or number of samples per pixels might not
    be supported by the hardware driver. Call
    **QOpenGLFramebufferObject::format** () after creating a
    **QOpenGLFramebufferObject**  to find the exact format that was used to
    create the frame buffer object.

    **See also** **QOpenGLFramebufferObject** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#QOpenGLFrameb
        ufferObjectFormat

        **QOpenGLFramebufferObjectFormat::QOpenGLFramebufferObjectFormat()**

        Creates a QOpenGLFramebufferObjectFormat object for specifying the
        format of an OpenGL framebuffer object.

        By default the format specifies a non-multisample framebuffer object
        with no depth/stencil attachments, texture target `GL_TEXTURE_2D`, and
        internal format `GL_RGBA8`. On OpenGL/ES systems, the default internal
        format is `GL_RGBA`.

        **See also** **samples** (), **attachment** (), and
        **internalTextureFormat** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QOpenGLFramebufferObjectFormat") -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#QOpenGLFrameb
        ufferObjectFormat-1

        **QOpenGLFramebufferObjectFormat::QOpenGLFramebufferObjectFormat(const
        QOpenGLFramebufferObjectFormat & other )**

        Constructs a copy of **other**.
        """
        ...

    def internalTextureFormat(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#internalTextu
        reFormat

        **GLenum QOpenGLFramebufferObjectFormat::internalTextureFormat() const**

        Returns the internal format of a framebuffer object's texture or
        multisample framebuffer object's color buffer. The default is `GL_RGBA8`
        on desktop OpenGL systems, and `GL_RGBA` on OpenGL/ES systems.

        **See also** **setInternalTextureFormat** ().
        """
        ...

    def setInternalTextureFormat(self, internalTextureFormat: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#setInternalTe
        xtureFormat

        **void QOpenGLFramebufferObjectFormat::setInternalTextureFormat(GLenum
        internalTextureFormat )**

        Sets the internal format of a framebuffer object's texture or
        multisample framebuffer object's color buffer to
        **internalTextureFormat**.

        **See also** **internalTextureFormat** ().
        """
        ...

    def textureTarget(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#textureTarget

        **GLenum QOpenGLFramebufferObjectFormat::textureTarget() const**

        Returns the texture target of the texture attached to a framebuffer
        object. Ignored for multisample framebuffer objects. The default is
        `GL_TEXTURE_2D`.

        **See also** **setTextureTarget** () and **samples** ().
        """
        ...

    def setTextureTarget(self, target: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#setTextureTar
        get

        **void QOpenGLFramebufferObjectFormat::setTextureTarget(GLenum target
        )**

        Sets the texture target of the texture attached to a framebuffer object
        to **target**. Ignored for multisample framebuffer objects.

        **See also** **textureTarget** () and **samples** ().
        """
        ...

    def attachment(self) -> QOpenGLFramebufferObject.Attachment:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#attachment

        **QOpenGLFramebufferObject::Attachment
        QOpenGLFramebufferObjectFormat::attachment() const**

        Returns the configuration of the depth and stencil buffers attached to a
        framebuffer object. The default is
        **QOpenGLFramebufferObject::NoAttachment** .

        **See also** **setAttachment** ().
        """
        ...

    def setAttachment(self, attachment: QOpenGLFramebufferObject.Attachment) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#setAttachment

        **void QOpenGLFramebufferObjectFormat::setAttachment(QOpenGLFramebufferO
        bject::Attachment attachment )**

        Sets the attachment configuration of a framebuffer object to
        **attachment**.

        **See also** **attachment** ().
        """
        ...

    def mipmap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#mipmap

        **bool QOpenGLFramebufferObjectFormat::mipmap() const**

        Returns `true` if mipmapping is enabled.

        **See also** **setMipmap** ().
        """
        ...

    def setMipmap(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#setMipmap

        **void QOpenGLFramebufferObjectFormat::setMipmap(bool enabled )**

        Enables mipmapping if **enabled** is true; otherwise disables it.

        Mipmapping is disabled by default.

        If mipmapping is enabled, additional memory will be allocated for the
        mipmap levels. The mipmap levels can be updated by binding the texture
        and calling glGenerateMipmap(). Mipmapping cannot be enabled for
        multisampled framebuffer objects.

        **See also** **mipmap** () and **QOpenGLFramebufferObject::texture** ().
        """
        ...

    def samples(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#samples

        **int QOpenGLFramebufferObjectFormat::samples() const**

        Returns the number of samples per pixel if a framebuffer object is a
        multisample framebuffer object. Otherwise, returns 0. The default value
        is 0.

        **See also** **setSamples** ().
        """
        ...

    def setSamples(self, samples: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglframebufferobjectformat.html#setSamples

        **void QOpenGLFramebufferObjectFormat::setSamples(int samples )**

        Sets the number of samples per pixel for a multisample framebuffer
        object to **samples**. The default sample count of 0 represents a
        regular non-multisample framebuffer object.

        If the desired amount of samples per pixel is not supported by the
        hardware then the maximum number of samples per pixel will be used. Note
        that multisample framebuffer objects cannot be bound as textures. Also,
        the `GL_EXT_framebuffer_multisample` extension is required to create a
        framebuffer with more than one sample per pixel.

        **See also** **samples** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QHideEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qhideevent.html

    **Detailed Description**

    This event is sent just before **QWidget::hide** () returns, and also when a
    top-level window has been hidden (iconified) by the user.

    If **spontaneous** () is true, the event originated outside the application.
    In this case, the user hid the window using the window manager controls,
    either by iconifying the window or by switching to another virtual desktop
    where the window is not visible. The window will become hidden but not
    withdrawn. If the window was iconified, **QWidget::isMinimized** () returns
    `true`.

    **See also** **QShowEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhideevent.html#QHideEvent-2

        **QHideEvent::QHideEvent()**

        Constructs a QHideEvent.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCommandLineParser(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcommandlineparser.html

    **Detailed Description**

    **QCoreApplication**  provides the command-line arguments as a simple list
    of strings. QCommandLineParser provides the ability to define a set of
    options, parse the command-line arguments, and store which options have
    actually been used, as well as option values.

    Any argument that isn't an option (i.e. doesn't start with a `-`) is stored
    as a "positional argument".

    The parser handles short names, long names, more than one name for the same
    option, and option values.

    Options on the command line are recognized as starting with a single or
    double `-` character(s). The option `-` (single dash alone) is a special
    case, often meaning standard input, and not treated as an option. The parser
    will treat everything after the option `--` (double dash) as positional
    arguments.

    Short options are single letters. The option `v` would be specified by
    passing `-v` on the command line. In the default parsing mode, short options
    can be written in a compact form, for instance `-abc` is equivalent to `-a
    -b -c`. The parsing mode for can be set to **ParseAsLongOptions** , in which
    case `-abc` will be parsed as the long option `abc`.

    Long options are more than one letter long and cannot be compacted together.
    The long option `verbose` would be passed as `--verbose` or `-verbose`.

    Passing values to options can be done using the assignment operator:
    `-v=value` `--verbose=value`, or a space: `-v value` `--verbose value`, i.e.
    the next argument is used as value (even if it starts with a `-`).

    The parser does not support optional values - if an option is set to require
    a value, one must be present. If such an option is placed last and has no
    value, the option will be treated as if it had not been specified.

    The parser does not automatically support negating or disabling long options
    by using the format `--disable-option` or `--no-option`. However, it is
    possible to handle this case explicitly by making an option with `no-option`
    as one of its names, and handling the option explicitly.

    Example:

    int main(int argc, char *argv[])
        {
            **QCoreApplication**
    app(argc, argv);
            **QCoreApplication** ::setApplicationName("my-copy-
    program");
            **QCoreApplication** ::setApplicationVersion("1.0");
    **QCommandLineParser**  parser;
    parser.setApplicationDescription("Test helper");
    parser.addHelpOption();
            parser.addVersionOption();
    parser.addPositionalArgument("source", **QCoreApplication**
    ::translate("main", "Source file to copy."));
    parser.addPositionalArgument("destination", **QCoreApplication**
    ::translate("main", "Destination directory."));

            // A boolean
    option with a single name (-p)
            **QCommandLineOption**
    showProgressOption("p", **QCoreApplication** ::translate("main", "Show
    progress during copy"));
            parser.addOption(showProgressOption);
    // A boolean option with multiple names (-f, --force)
    **QCommandLineOption**  forceOption(**QStringList** () << "f" << "force",
    **QCoreApplication** ::translate("main", "Overwrite existing files."));
    parser.addOption(forceOption);

            // An option with a value
    **QCommandLineOption**  targetDirectoryOption(**QStringList** () << "t" <<
    "target-directory",
                    **QCoreApplication** ::translate("main",
    "Copy all source files into <directory>."),
    **QCoreApplication** ::translate("main", "directory"));
    parser.addOption(targetDirectoryOption);

            // Process the actual
    command line arguments given by the user
            parser.process(app);
    const **QStringList**  args = parser.positionalArguments();
            //
    source is args.at(0), destination is args.at(1)

            bool
    showProgress = parser.isSet(showProgressOption);
            bool force =
    parser.isSet(forceOption);
            **QString**  targetDir =
    parser.value(targetDirectoryOption);
            // ...
        }

    If your compiler supports the C++11 standard, the three **addOption** ()
    calls in the above example can be simplified:

    parser.addOptions({
                // A boolean option with a single name (-p)
    {"p",
                    **QCoreApplication** ::translate("main", "Show
    progress during copy")},
                // A boolean option with multiple names
    (-f, --force)
                {{"f", "force"},
    **QCoreApplication** ::translate("main", "Overwrite existing files.")},
    // An option with a value
                {{"t", "target-directory"},
    **QCoreApplication** ::translate("main", "Copy all source files into
    <directory>."),
                    **QCoreApplication** ::translate("main",
    "directory")},
            });

    Known limitation: the parsing of Qt options inside **QCoreApplication**  and
    subclasses happens before QCommandLineParser exists, so it can't take it
    into account. This means any option value that looks like a builtin Qt
    option, will be treated by **QCoreApplication**  as a builtin Qt option.
    Example: `--profile -reverse` will lead to **QGuiApplication**  seeing the
    -reverse option set, and removing it from **QCoreApplication::arguments** ()
    before QCommandLineParser defines the `profile` option and parses the
    command line.

    **How to Use QCommandLineParser in Complex Applications**

    In practice, additional error checking needs to be performed on the
    positional arguments and option values. For example, ranges of numbers
    should be checked.

    It is then advisable to introduce a function to do the command line parsing
    which takes a struct or class receiving the option values returning an
    enumeration representing the result. The dnslookup example of the
    **QtNetwork**  module illustrates this:

    struct DnsQuery
        {
            DnsQuery() : type(**QDnsLookup** ::A) {}
    **QDnsLookup** ::Type type;
            **QHostAddress**  nameServer;
    **QString**  name;
        };

        enum CommandLineParseResult
        {
    CommandLineOk,
            CommandLineError,
    CommandLineVersionRequested,
            CommandLineHelpRequested
        };
    CommandLineParseResult parseCommandLine(**QCommandLineParser**  &parser,
    DnsQuery *query, **QString**  *errorMessage)
        {
    parser.setSingleDashWordOptionMode(**QCommandLineParser**
    ::ParseAsLongOptions);
            const **QCommandLineOption**
    nameServerOption("n", "The name server to use.", "nameserver");
    parser.addOption(nameServerOption);
            const **QCommandLineOption**
    typeOption("t", "The lookup type.", "type");
    parser.addOption(typeOption);
            parser.addPositionalArgument("name",
    "The name to look up.");
            const **QCommandLineOption**  helpOption =
    parser.addHelpOption();
            const **QCommandLineOption**  versionOption
    = parser.addVersionOption();

            if
    (!parser.parse(**QCoreApplication** ::arguments())) {
    *errorMessage = parser.errorText();
                return CommandLineError;
    }

            if (parser.isSet(versionOption))
                return
    CommandLineVersionRequested;

            if (parser.isSet(helpOption))
    return CommandLineHelpRequested;

            if
    (parser.isSet(nameServerOption)) {
                const **QString**  nameserver
    = parser.value(nameServerOption);
                query->nameServer =
    **QHostAddress** (nameserver);
                if (query->nameServer.isNull() ||
    query->nameServer.protocol() == **QAbstractSocket**
    ::UnknownNetworkLayerProtocol) {
                    *errorMessage = "Bad
    nameserver address: " + nameserver;
                    return CommandLineError;
    }
            }

            if (parser.isSet(typeOption)) {
                const
    **QString**  typeParameter = parser.value(typeOption);
                const int
    type = typeFromParameter(typeParameter.toLower());
                if (type < 0)
    {
                    *errorMessage = "Bad record type: " + typeParameter;
    return CommandLineError;
                }
                query->type =
    static_cast<**QDnsLookup** ::Type>(type);
            }

            const
    **QStringList**  positionalArguments = parser.positionalArguments();
    if (positionalArguments.isEmpty()) {
                *errorMessage = "Argument
    'name' missing.";
                return CommandLineError;
            }
            if
    (positionalArguments.size() > 1) {
                *errorMessage = "Several
    'name' arguments specified.";
                return CommandLineError;
            }
    query->name = positionalArguments.first();

            return
    CommandLineOk;
        }

    In the main function, help should be printed to the standard output if the
    help option was passed and the application should return the exit code 0.

    If an error was detected, the error message should be printed to the
    standard error output and the application should return an exit code other
    than 0.

    **QCoreApplication** ::setApplicationVersion(QT_VERSION_STR);
    **QCoreApplication** ::setApplicationName(**QCoreApplication**
    ::translate("QDnsLookupExample", "DNS Lookup Example"));
    **QCommandLineParser**  parser;
    parser.setApplicationDescription(**QCoreApplication**
    ::translate("QDnsLookupExample", "An example demonstrating the class
    QDnsLookup."));
            DnsQuery query;
            **QString**  errorMessage;
    switch (parseCommandLine(parser, &query, &errorMessage)) {
            case
    CommandLineOk:
                break;
            case CommandLineError:
    fputs(**qPrintable** (errorMessage), stderr);
                fputs("\\n\\n",
    stderr);
                fputs(**qPrintable** (parser.helpText()), stderr);
    return 1;
            case CommandLineVersionRequested:
                printf("%s
    %s\\n", **qPrintable** (**QCoreApplication** ::applicationName()),
    **qPrintable** (**QCoreApplication** ::applicationVersion()));
    return 0;
            case CommandLineHelpRequested:
    parser.showHelp();
                Q_UNREACHABLE();
            }

    A special case to consider here are GUI applications on Windows and mobile
    platforms. These applications may not use the standard output or error
    channels since the output is either discarded or not accessible.

    On Windows, QCommandLineParser uses message boxes to display usage
    information and errors if no console window can be obtained.

    For other platforms, it is recommended to display help texts and error
    messages using a **QMessageBox** . To preserve the formatting of the help
    text, rich text with `<pre>` elements should be used:

    switch (parseCommandLine(parser, &query, &errorMessage)) {
        case
    CommandLineOk:
            break;
        case CommandLineError:
    **QMessageBox** ::warning(0, **QGuiApplication** ::applicationDisplayName(),
    "<html><head/><body><h2>" + errorMessage + "</h2><pre>"
    + parser.helpText() + "</pre></body></html>");
            return 1;
        case
    CommandLineVersionRequested:
            **QMessageBox** ::information(0,
    **QGuiApplication** ::applicationDisplayName(),
    **QGuiApplication** ::applicationDisplayName() + ' '
    + **QCoreApplication** ::applicationVersion());
            return 0;
        case
    CommandLineHelpRequested:
            **QMessageBox** ::warning(0,
    **QGuiApplication** ::applicationDisplayName(),
    "<html><head/><body><pre>"
                                 + parser.helpText()
    + "</pre></body></html>");
            return 0;
        }

    However, this does not apply to the dnslookup example, because it is a
    console application.

    **See also** **QCommandLineOption**  and **QCoreApplication** .
    """

    class OptionsAfterPositionalArgumentsMode(enum.Enum):
        ParseAsOptions: QCommandLineParser = ...
        ParseAsPositionalArguments: QCommandLineParser = ...

    class SingleDashWordOptionMode(enum.Enum):
        ParseAsCompactedShortOptions: QCommandLineParser = ...
        ParseAsLongOptions: QCommandLineParser = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#QCommandLineParser

        **QCommandLineParser::QCommandLineParser()**

        Constructs a command line parser object.
        """
        ...

    def setOptionsAfterPositionalArgumentsMode(
        self, mode: "QCommandLineParser.OptionsAfterPositionalArgumentsMode"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#setOptionsAfterPositional
        ArgumentsMode

        **[since 5.6] void QCommandLineParser::setOptionsAfterPositionalArgument
        sMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode
        parsingMode )**

        Sets the parsing mode to **parsingMode**. This must be called before
        **process** () or **parse** ().

        This function was introduced in Qt 5.6.
        """
        ...

    def showVersion(self) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#showVersion

        **[since 5.4] void QCommandLineParser::showVersion()**

        Displays the version information from
        **QCoreApplication::applicationVersion** (), and exits the application.
        This is automatically triggered by the --version option, but can also be
        used to display the version when not using **process** (). The exit code
        is set to EXIT_SUCCESS (0).

        This function was introduced in Qt 5.4.

        **See also** **addVersionOption** ().
        """
        ...

    def addOptions(self, options: typing.Iterable[QCommandLineOption]) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#addOptions

        **[since 5.4] bool QCommandLineParser::addOptions(const
        QList<QCommandLineOption> & options )**

        Adds the options to look for while parsing. The options are specified by
        the parameter **options**.

        Returns `true` if adding all of the options was successful; otherwise
        returns `false`.

        See the documentation for **addOption** () for when this function may
        fail.

        This function was introduced in Qt 5.4.
        """
        ...

    def helpText(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#helpText

        **QString QCommandLineParser::helpText() const**

        Returns a string containing the complete help information.

        **See also** **showHelp** ().
        """
        ...

    def showHelp(self, exitCode: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#showHelp

        **void QCommandLineParser::showHelp(int exitCode = 0)**

        Displays the help information, and exits the application. This is
        automatically triggered by the --help option, but can also be used to
        display the help when the user is not invoking the application
        correctly. The exit code is set to **exitCode**. It should be set to 0
        if the user requested to see the help, and to any other value in case of
        an error.

        **See also** **helpText** ().
        """
        ...

    def unknownOptionNames(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#unknownOptionNames

        **QStringList QCommandLineParser::unknownOptionNames() const**

        Returns a list of unknown option names.

        This list will include both long an short name options that were not
        recognized. For any long options that were in the form {--option=value},
        the value part will have been dropped and only the long name is added.

        The names in this list do not include the preceding dash characters.
        Names may appear more than once in this list if they were encountered
        more than once by the parser.

        **See also** **optionNames** ().
        """
        ...

    def optionNames(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#optionNames

        **QStringList QCommandLineParser::optionNames() const**

        Returns a list of option names that were found.

        This returns a list of all the recognized option names found by the
        parser, in the order in which they were found. For any long options that
        were in the form {--option=value}, the value part will have been
        dropped.

        The names in this list do not include the preceding dash characters.
        Names may appear more than once in this list if they were encountered
        more than once by the parser.

        Any entry in the list can be used with `value()` or with `values()` to
        get any relevant option values.
        """
        ...

    def positionalArguments(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#positionalArguments

        **QStringList QCommandLineParser::positionalArguments() const**

        Returns a list of positional arguments.

        These are all of the arguments that were not recognized as part of an
        option.
        """
        ...

    @typing.overload
    def values(self, name: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#values

        **QStringList QCommandLineParser::values(const QString & optionName )
        const**

        Returns a list of option values found for the given option name
        **optionName** , or an empty list if not found.

        The name provided can be any long or short name of any option that was
        added with `addOption()`. All the options names are treated as being
        equivalent. If the name is not recognized or that option was not
        present, an empty list is returned.

        For options found by the parser, the list will contain an entry for each
        time the option was encountered by the parser. If the option wasn't
        specified on the command line, the default values are returned.

        An empty list is returned if the option does not take a value.

        **See also** **value** (), **QCommandLineOption::setDefaultValue** (),
        and **QCommandLineOption::setDefaultValues** ().
        """
        ...

    @typing.overload
    def values(self, option: QCommandLineOption) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#values-1

        **QStringList QCommandLineParser::values(const QCommandLineOption &
        option ) const**

        This is an overloaded function.

        Returns a list of option values found for the given **option** , or an
        empty list if not found.

        For options found by the parser, the list will contain an entry for each
        time the option was encountered by the parser. If the option wasn't
        specified on the command line, the default values are returned.

        An empty list is returned if the option does not take a value.

        **See also** **value** (), **QCommandLineOption::setDefaultValue** (),
        and **QCommandLineOption::setDefaultValues** ().
        """
        ...

    @typing.overload
    def value(self, name: str) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#value

        **QString QCommandLineParser::value(const QString & optionName ) const**

        Returns the option value found for the given option name **optionName**
        , or an empty string if not found.

        The name provided can be any long or short name of any option that was
        added with `addOption()`. All the option names are treated as being
        equivalent. If the name is not recognized or that option was not
        present, an empty string is returned.

        For options found by the parser, the last value found for that option is
        returned. If the option wasn't specified on the command line, the
        default value is returned.

        An empty string is returned if the option does not take a value.

        **See also** **values** (), **QCommandLineOption::setDefaultValue** (),
        and **QCommandLineOption::setDefaultValues** ().
        """
        ...

    @typing.overload
    def value(self, option: QCommandLineOption) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#value-1

        **QString QCommandLineParser::value(const QCommandLineOption & option )
        const**

        This is an overloaded function.

        Returns the option value found for the given **option** , or an empty
        string if not found.

        For options found by the parser, the last value found for that option is
        returned. If the option wasn't specified on the command line, the
        default value is returned.

        An empty string is returned if the option does not take a value.

        **See also** **values** (), **QCommandLineOption::setDefaultValue** (),
        and **QCommandLineOption::setDefaultValues** ().
        """
        ...

    @typing.overload
    def isSet(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#isSet

        **bool QCommandLineParser::isSet(const QString & name ) const**

        Checks whether the option **name** was passed to the application.

        Returns `true` if the option **name** was set, false otherwise.

        The name provided can be any long or short name of any option that was
        added with `addOption()`. All the options names are treated as being
        equivalent. If the name is not recognized or that option was not
        present, false is returned.

        Example:

        bool verbose = parser.isSet("verbose");
        """
        ...

    @typing.overload
    def isSet(self, option: QCommandLineOption) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#isSet-1

        **bool QCommandLineParser::isSet(const QCommandLineOption & option )
        const**

        This is an overloaded function.

        Checks whether the **option** was passed to the application.

        Returns `true` if the **option** was set, false otherwise.

        This is the recommended way to check for options with no values.

        Example:

        **QCoreApplication**  app(argc, argv);
            **QCommandLineParser**
        parser;
            **QCommandLineOption**  verboseOption("verbose");
        parser.addOption(verboseOption);
            parser.process(app);
            bool
        verbose = parser.isSet(verboseOption);
        """
        ...

    def errorText(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#errorText

        **QString QCommandLineParser::errorText() const**

        Returns a translated error text for the user. This should only be called
        when **parse** () returns `false`.
        """
        ...

    def parse(self, arguments: typing.Iterable[str]) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#parse

        **bool QCommandLineParser::parse(const QStringList & arguments )**

        Parses the command line **arguments**.

        Most programs don't need to call this, a simple call to **process** ()
        is enough.

        parse() is more low-level, and only does the parsing. The application
        will have to take care of the error handling, using **errorText** () if
        parse() returns `false`. This can be useful for instance to show a
        graphical error message in graphical programs.

        Calling parse() instead of **process** () can also be useful in order to
        ignore unknown options temporarily, because more option definitions will
        be provided later on (depending on one of the arguments), before calling
        **process** ().

        Don't forget that **arguments** must start with the name of the
        executable (ignored, though).

        Returns `false` in case of a parse error (unknown option or missing
        value); returns `true` otherwise.

        **See also** **process** ().
        """
        ...

    @typing.overload
    def process(self, arguments: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#process

        **void QCommandLineParser::process(const QStringList & arguments )**

        Processes the command line **arguments**.

        In addition to parsing the options (like **parse** ()), this function
        also handles the builtin options and handles errors.

        The builtin options are `--version` if **addVersionOption**  was called
        and `--help` / `--help-all` if **addHelpOption**  was called.

        When invoking one of these options, or when an error happens (for
        instance an unknown option was passed), the current process will then
        stop, using the exit() function.

        **See also** **QCoreApplication::arguments** () and **parse** ().
        """
        ...

    @typing.overload
    def process(self, app: "QCoreApplication") -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#process-1

        **void QCommandLineParser::process(const QCoreApplication & app )**

        This is an overloaded function.

        The command line is obtained from the **QCoreApplication**  instance
        **app**.
        """
        ...

    def clearPositionalArguments(self) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#clearPositionalArguments

        **void QCommandLineParser::clearPositionalArguments()**

        Clears the definitions of additional arguments from the help text.

        This is only needed for the special case of tools which support multiple
        commands with different options. Once the actual command has been
        identified, the options for this command can be defined, and the help
        text for the command can be adjusted accordingly.

        Example:

        **QCoreApplication**  app(argc, argv);
            **QCommandLineParser**
        parser;

            parser.addPositionalArgument("command", "The command to
        execute.");

            // Call parse() to find out the positional
        arguments.
            parser.parse(**QCoreApplication** ::arguments());
        const **QStringList**  args = parser.positionalArguments();
            const
        **QString**  command = args.isEmpty() ? **QString** () : args.first();
        if (command == "resize") {
                parser.clearPositionalArguments();
        parser.addPositionalArgument("resize", "Resize the object to a new
        size.", "resize [resize_options]");
        parser.addOption(**QCommandLineOption** ("size", "New size.",
        "new_size"));
                parser.process(app);
                // ...
            }
        /*
            This code results in context-dependent help:

            $ tool
        --help
            Usage: tool command

            Arguments:
              command  The
        command to execute.

            $ tool resize --help
            Usage: tool resize
        [resize_options]

            Options:
              --size <size>  New size.
        Arguments:
              resize         Resize the object to a new size.
            */
        """
        ...

    def addPositionalArgument(
        self, name: str, description: str, syntax: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#addPositionalArgument

        **void QCommandLineParser::addPositionalArgument(const QString & name ,
        const QString & description , const QString & syntax = QString())**

        Defines an additional argument to the application, for the benefit of
        the help text.

        The argument **name** and **description** will appear under the
        `Arguments:` section of the help. If **syntax** is specified, it will be
        appended to the Usage line, otherwise the **name** will be appended.

        Example:

        // Usage: image-editor file
            //
            // Arguments:
            //   file
        The file to open.
            parser.addPositionalArgument("file",
        **QCoreApplication** ::translate("main", "The file to open."));
        // Usage: web-browser [urls...]
            //
            // Arguments:
            //   urls
        URLs to open, optionally.
            parser.addPositionalArgument("urls",
        **QCoreApplication** ::translate("main", "URLs to open, optionally."),
        "[urls...]");

            // Usage: cp source destination
            //
            //
        Arguments:
            //   source                Source file to copy.
            //
        destination           Destination directory.
        parser.addPositionalArgument("source", **QCoreApplication**
        ::translate("main", "Source file to copy."));
        parser.addPositionalArgument("destination", **QCoreApplication**
        ::translate("main", "Destination directory."));

        **See also** **addHelpOption** () and **helpText** ().
        """
        ...

    def applicationDescription(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#applicationDescription

        **QString QCommandLineParser::applicationDescription() const**

        Returns the application description set in **setApplicationDescription**
        ().

        **See also** **setApplicationDescription** ().
        """
        ...

    def setApplicationDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#setApplicationDescription

        **void QCommandLineParser::setApplicationDescription(const QString &
        description )**

        Sets the application **description** shown by **helpText** ().

        **See also** **applicationDescription** ().
        """
        ...

    def addHelpOption(self) -> QCommandLineOption:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#addHelpOption

        **QCommandLineOption QCommandLineParser::addHelpOption()**

        Adds the help option (`-h`, `--help` and `-?` on Windows) as well as an
        option `--help-all` to include Qt-specific options in the output.

        These options are handled automatically by **QCommandLineParser** .

        Remember to use **setApplicationDescription**  to set the application
        description, which will be displayed when this option is used.

        Example:

        int main(int argc, char *argv[])
            {
                **QCoreApplication**
        app(argc, argv);
                **QCoreApplication** ::setApplicationName("my-
        copy-program");
                **QCoreApplication**
        ::setApplicationVersion("1.0");

                **QCommandLineParser**
        parser;
                parser.setApplicationDescription("Test helper");
        parser.addHelpOption();
                parser.addVersionOption();
        parser.addPositionalArgument("source", **QCoreApplication**
        ::translate("main", "Source file to copy."));
        parser.addPositionalArgument("destination", **QCoreApplication**
        ::translate("main", "Destination directory."));

                // A
        boolean option with a single name (-p)
                **QCommandLineOption**
        showProgressOption("p", **QCoreApplication** ::translate("main", "Show
        progress during copy"));
                parser.addOption(showProgressOption);
        // A boolean option with multiple names (-f, --force)
        **QCommandLineOption**  forceOption(**QStringList** () << "f" <<
        "force",
                        **QCoreApplication** ::translate("main",
        "Overwrite existing files."));
                parser.addOption(forceOption);
        // An option with a value
                **QCommandLineOption**
        targetDirectoryOption(**QStringList** () << "t" << "target-directory",
        **QCoreApplication** ::translate("main", "Copy all source files into
        <directory>."),
                        **QCoreApplication** ::translate("main",
        "directory"));
                parser.addOption(targetDirectoryOption);
        // Process the actual command line arguments given by the user
        parser.process(app);

                const **QStringList**  args =
        parser.positionalArguments();
                // source is args.at(0),
        destination is args.at(1)

                bool showProgress =
        parser.isSet(showProgressOption);
                bool force =
        parser.isSet(forceOption);
                **QString**  targetDir =
        parser.value(targetDirectoryOption);
                // ...
            }

        Returns the option instance, which can be used to call **isSet** ().
        """
        ...

    def addVersionOption(self) -> QCommandLineOption:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#addVersionOption

        **QCommandLineOption QCommandLineParser::addVersionOption()**

        Adds the `-v` / `--version` option, which displays the version string of
        the application.

        This option is handled automatically by **QCommandLineParser** .

        You can set the actual version string by using
        **QCoreApplication::setApplicationVersion** ().

        Returns the option instance, which can be used to call **isSet** ().
        """
        ...

    def addOption(self, commandLineOption: QCommandLineOption) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#addOption

        **bool QCommandLineParser::addOption(const QCommandLineOption & option
        )**

        Adds the option **option** to look for while parsing.

        Returns `true` if adding the option was successful; otherwise returns
        `false`.

        Adding the option fails if there is no name attached to the option, or
        the option has a name that clashes with an option name added before.
        """
        ...

    def setSingleDashWordOptionMode(
        self, parsingMode: "QCommandLineParser.SingleDashWordOptionMode"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlineparser.html#setSingleDashWordOptionMo
        de

        **void QCommandLineParser::setSingleDashWordOptionMode(QCommandLineParse
        r::SingleDashWordOptionMode singleDashWordOptionMode )**

        Sets the parsing mode to **singleDashWordOptionMode**. This must be
        called before **process** () or **parse** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QThreadPool(QObject):
    """
    https://doc.qt.io/qt-6/qthreadpool.html

    **Detailed Description**

    QThreadPool manages and recycles individual **QThread**  objects to help
    reduce thread creation costs in programs that use threads. Each Qt
    application has one global QThreadPool object, which can be accessed by
    calling **globalInstance** ().

    To use one of the QThreadPool threads, subclass **QRunnable**  and implement
    the run() virtual function. Then create an object of that class and pass it
    to **QThreadPool::start** ().

    class HelloWorldTask : public **QRunnable**
        {
            void run()
    override
            {
                **qDebug** () << "Hello world from thread" <<
    **QThread** ::currentThread();
            }
        };

        HelloWorldTask
    *hello = new HelloWorldTask();
        // QThreadPool takes ownership and
    deletes 'hello' automatically
        **QThreadPool**
    ::globalInstance()->start(hello);

    QThreadPool deletes the **QRunnable**  automatically by default. Use
    **QRunnable::setAutoDelete** () to change the auto-deletion flag.

    QThreadPool supports executing the same **QRunnable**  more than once by
    calling **tryStart** (this) from within **QRunnable::run** (). If autoDelete
    is enabled the **QRunnable**  will be deleted when the last thread exits the
    run function. Calling **start** () multiple times with the same
    **QRunnable**  when autoDelete is enabled creates a race condition and is
    not recommended.

    Threads that are unused for a certain amount of time will expire. The
    default expiry timeout is 30000 milliseconds (30 seconds). This can be
    changed using **setExpiryTimeout** (). Setting a negative expiry timeout
    disables the expiry mechanism.

    Call **maxThreadCount** () to query the maximum number of threads to be
    used. If needed, you can change the limit with **setMaxThreadCount** (). The
    default **maxThreadCount** () is **QThread::idealThreadCount** (). The
    **activeThreadCount** () function returns the number of threads currently
    doing work.

    The **reserveThread** () function reserves a thread for external use. Use
    **releaseThread** () when your are done with the thread, so that it may be
    reused. Essentially, these functions temporarily increase or reduce the
    active thread count and are useful when implementing time-consuming
    operations that are not visible to the QThreadPool.

    Note that QThreadPool is a low-level class for managing threads, see the Qt
    Concurrent module for higher level alternatives.

    **See also** **QRunnable** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#QThreadPool

        **QThreadPool::QThreadPool(QObject * parent = nullptr)**

        Constructs a thread pool with the given **parent**.
        """
        ...

    def threadPriority(self) -> QThread.Priority:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#threadPriority-prop

        **[since 6.2] threadPriority : QThread::Priority**

        This property holds the thread priority for new worker threads.

        The value of the property is only used when the thread pool starts new
        threads. Changing it has no effect for already running threads.

        The default value is **QThread::InheritPriority** , which makes
        **QThread**  use the same priority as the one the **QThreadPool**
        object lives in.

        This property was introduced in Qt 6.2.

        **Access functions:**

        QThread::Priority **threadPriority** () const
        void
        **setThreadPriority** (QThread::Priority **priority** )

        **See also** **QThread::Priority** .

        **Member Function Documentation**
        """
        ...

    def setThreadPriority(self, priority: QThread.Priority) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#threadPriority-prop

        **[since 6.2] threadPriority : QThread::Priority**

        This property holds the thread priority for new worker threads.

        The value of the property is only used when the thread pool starts new
        threads. Changing it has no effect for already running threads.

        The default value is **QThread::InheritPriority** , which makes
        **QThread**  use the same priority as the one the **QThreadPool**
        object lives in.

        This property was introduced in Qt 6.2.

        **Access functions:**

        QThread::Priority **threadPriority** () const
        void
        **setThreadPriority** (QThread::Priority **priority** )

        **See also** **QThread::Priority** .

        **Member Function Documentation**
        """
        ...

    def contains(self, thread: QThread) -> bool:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#contains

        **[since 6.0] bool QThreadPool::contains(const QThread * thread )
        const**

        Returns `true` if **thread** is a thread managed by this thread pool.

        This function was introduced in Qt 6.0.
        """
        ...

    def stackSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#stackSize-prop

        **[since 5.10] stackSize : uint**

        This property holds the stack size for the thread pool worker threads.

        The value of the property is only used when the thread pool creates new
        threads. Changing it has no effect for already created or running
        threads.

        The default value is 0, which makes **QThread**  use the operating
        system default stack size.

        This property was introduced in Qt 5.10.

        **Access functions:**

        uint **stackSize** () const
        void **setStackSize** (uint **stackSize**
        )
        """
        ...

    def setStackSize(self, stackSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#stackSize-prop

        **[since 5.10] stackSize : uint**

        This property holds the stack size for the thread pool worker threads.

        The value of the property is only used when the thread pool creates new
        threads. Changing it has no effect for already created or running
        threads.

        The default value is 0, which makes **QThread**  use the operating
        system default stack size.

        This property was introduced in Qt 5.10.

        **Access functions:**

        uint **stackSize** () const
        void **setStackSize** (uint **stackSize**
        )
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#clear

        **[since 5.2] void QThreadPool::clear()**

        Removes the runnables that are not yet started from the queue. The
        runnables for which **runnable->autoDelete** () returns `true` are
        deleted.

        This function was introduced in Qt 5.2.

        **See also** **start** ().
        """
        ...

    def waitForDone(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#waitForDone

        **bool QThreadPool::waitForDone(int msecs = -1)**

        Waits up to **msecs** milliseconds for all threads to exit and removes
        all threads from the thread pool. Returns `true` if all threads were
        removed; otherwise it returns `false`. If **msecs** is -1 (the default),
        the timeout is ignored (waits for the last thread to exit).
        """
        ...

    def releaseThread(self) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#releaseThread

        **void QThreadPool::releaseThread()**

        Releases a thread previously reserved by a call to **reserveThread** ().

        **Note:** Calling this function without previously reserving a thread
        temporarily increases **maxThreadCount** (). This is useful when a
        thread goes to sleep waiting for more work, allowing other threads to
        continue. Be sure to call **reserveThread** () when done waiting, so
        that the thread pool can correctly maintain the **activeThreadCount**
        ().

        **See also** **reserveThread** ().
        """
        ...

    def reserveThread(self) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#reserveThread

        **void QThreadPool::reserveThread()**

        Reserves one thread, disregarding **activeThreadCount** () and
        **maxThreadCount** ().

        Once you are done with the thread, call **releaseThread** () to allow it
        to be reused.

        **Note:** Even if reserving **maxThreadCount** () threads or more, the
        thread pool will still allow a minimum of one thread.

        **Note:** This function will increase the reported number of active
        threads. This means that by using this function, it is possible for
        **activeThreadCount** () to return a value greater than
        **maxThreadCount** () .

        **See also** **releaseThread** ().
        """
        ...

    def activeThreadCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#activeThreadCount-prop

        **[read-only] activeThreadCount : const int**

        This property holds the number of active threads in the thread pool.

        **Note:** It is possible for this function to return a value that is
        greater than **maxThreadCount** (). See **reserveThread** () for more
        details.

        **Access functions:**

        int **activeThreadCount** () const

        **See also** **reserveThread** () and **releaseThread** ().
        """
        ...

    def setMaxThreadCount(self, maxThreadCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#maxThreadCount-prop

        **maxThreadCount : int**

        This property holds the maximum number of threads used by the thread
        pool. This property will default to the value of
        **QThread::idealThreadCount** () at the moment the **QThreadPool**
        object is created.

        **Note:** The thread pool will always use at least 1 thread, even if
        **maxThreadCount** limit is zero or negative.

        The default **maxThreadCount** is **QThread::idealThreadCount** ().

        **Access functions:**

        int **maxThreadCount** () const
        void **setMaxThreadCount** (int
        **maxThreadCount** )
        """
        ...

    def maxThreadCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#maxThreadCount-prop

        **maxThreadCount : int**

        This property holds the maximum number of threads used by the thread
        pool. This property will default to the value of
        **QThread::idealThreadCount** () at the moment the **QThreadPool**
        object is created.

        **Note:** The thread pool will always use at least 1 thread, even if
        **maxThreadCount** limit is zero or negative.

        The default **maxThreadCount** is **QThread::idealThreadCount** ().

        **Access functions:**

        int **maxThreadCount** () const
        void **setMaxThreadCount** (int
        **maxThreadCount** )
        """
        ...

    def setExpiryTimeout(self, expiryTimeout: int) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#expiryTimeout-prop

        **expiryTimeout : int**

        This property holds the thread expiry timeout value in milliseconds.

        Threads that are unused for **expiryTimeout** milliseconds are
        considered to have expired and will exit. Such threads will be restarted
        as needed. The default **expiryTimeout** is 30000 milliseconds (30
        seconds). If **expiryTimeout** is negative, newly created threads will
        not expire, e.g., they will not exit until the thread pool is destroyed.

        Note that setting **expiryTimeout** has no effect on already running
        threads. Only newly created threads will use the new **expiryTimeout**.
        We recommend setting the **expiryTimeout** immediately after creating
        the thread pool, but before calling **start** ().

        **Access functions:**

        int **expiryTimeout** () const
        void **setExpiryTimeout** (int
        **expiryTimeout** )
        """
        ...

    def expiryTimeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#expiryTimeout-prop

        **expiryTimeout : int**

        This property holds the thread expiry timeout value in milliseconds.

        Threads that are unused for **expiryTimeout** milliseconds are
        considered to have expired and will exit. Such threads will be restarted
        as needed. The default **expiryTimeout** is 30000 milliseconds (30
        seconds). If **expiryTimeout** is negative, newly created threads will
        not expire, e.g., they will not exit until the thread pool is destroyed.

        Note that setting **expiryTimeout** has no effect on already running
        threads. Only newly created threads will use the new **expiryTimeout**.
        We recommend setting the **expiryTimeout** immediately after creating
        the thread pool, but before calling **start** ().

        **Access functions:**

        int **expiryTimeout** () const
        void **setExpiryTimeout** (int
        **expiryTimeout** )
        """
        ...

    def tryTake(self, runnable: QRunnable) -> bool:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#tryTake

        **[since 5.9] bool QThreadPool::tryTake(QRunnable * runnable )**

        Attempts to remove the specified **runnable** from the queue if it is
        not yet started. If the runnable had not been started, returns `true`,
        and ownership of **runnable** is transferred to the caller (even when
        `runnable->autoDelete() == true`). Otherwise returns `false`.

        **Note:** If `runnable->autoDelete() == true`, this function may remove
        the wrong runnable. This is known as the **ABA problem** : the original
        **runnable** may already have executed and has since been deleted. The
        memory is re-used for another runnable, which then gets removed instead
        of the intended one. For this reason, we recommend calling this function
        only for runnables that are not auto-deleting.

        This function was introduced in Qt 5.9.

        **See also** **start** () and **QRunnable::autoDelete** ().
        """
        ...

    @typing.overload
    def tryStart(self, runnable: QRunnable) -> bool:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#tryStart

        **bool QThreadPool::tryStart(QRunnable * runnable )**

        Attempts to reserve a thread to run **runnable**.

        If no threads are available at the time of calling, then this function
        does nothing and returns `false`. Otherwise, **runnable** is run
        immediately using one available thread and this function returns `true`.

        Note that on success the thread pool takes ownership of the **runnable**
        if **runnable->autoDelete** () returns `true`, and the **runnable** will
        be deleted automatically by the thread pool after the **runnable->run**
        () returns. If **runnable->autoDelete** () returns `false`, ownership of
        **runnable** remains with the caller. Note that changing the auto-
        deletion on **runnable** after calling this function results in
        undefined behavior.
        """
        ...

    @typing.overload
    def tryStart(self, functionToRun: typing.Callable[[], None]) -> bool:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#tryStart-1

        **[since 5.15] bool QThreadPool::tryStart(std::function<void ()>
        functionToRun )**

        This is an overloaded function.

        Attempts to reserve a thread to run **functionToRun**.

        If no threads are available at the time of calling, then this function
        does nothing and returns `false`. Otherwise, **functionToRun** is run
        immediately using one available thread and this function returns `true`.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def start(self, runnable: QRunnable, priority: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#start

        **void QThreadPool::start(QRunnable * runnable , int priority = 0)**

        Reserves a thread and uses it to run **runnable** , unless this thread
        will make the current thread count exceed **maxThreadCount** (). In that
        case, **runnable** is added to a run queue instead. The **priority**
        argument can be used to control the run queue's order of execution.

        Note that the thread pool takes ownership of the **runnable** if
        **runnable->autoDelete** () returns `true`, and the **runnable** will be
        deleted automatically by the thread pool after the **runnable->run** ()
        returns. If **runnable->autoDelete** () returns `false`, ownership of
        **runnable** remains with the caller. Note that changing the auto-
        deletion on **runnable** after calling this functions results in
        undefined behavior.
        """
        ...

    @typing.overload
    def start(
        self, functionToRun: typing.Callable[[], None], priority: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qthreadpool.html#start-1

        **[since 5.15] void QThreadPool::start(std::function<void ()>
        functionToRun , int priority = 0)**

        This is an overloaded function.

        Reserves a thread and uses it to run **functionToRun** , unless this
        thread will make the current thread count exceed **maxThreadCount** ().
        In that case, **functionToRun** is added to a run queue instead. The
        **priority** argument can be used to control the run queue's order of
        execution.

        This function was introduced in Qt 5.15.
        """
        ...

    @staticmethod
    def globalInstance() -> "QThreadPool":
        """
        https://doc.qt.io/qt-6/qthreadpool.html#globalInstance

        **[static] QThreadPool *QThreadPool::globalInstance()**

        Returns the global **QThreadPool**  instance.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QSslConfiguration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslconfiguration.html

    **Detailed Description**

    QSslConfiguration is used by Qt networking classes to relay information
    about an open SSL connection and to allow the application to control certain
    features of that connection.

    The settings that QSslConfiguration currently supports are:

    * The SSL/TLS protocol to be used
      * The certificate to be presented to the
    peer during connection and its associated private key
      * The ciphers
    allowed to be used for encrypting the connection
      * The list of Certificate
    Authorities certificates that are used to validate the peer's certificate

    These settings are applied only during the connection handshake. Setting
    them after the connection has been established has no effect.

    The state that QSslConfiguration supports are:

    * The certificate the peer presented during handshake, along with the chain
    leading to a CA certificate
      * The cipher used to encrypt this session

    The state can only be obtained once the SSL connection starts, but not
    necessarily before it's done. Some settings may change during the course of
    the SSL connection without need to restart it (for instance, the cipher can
    be changed over time).

    State in QSslConfiguration objects cannot be changed.

    QSslConfiguration can be used with **QSslSocket**  and the Network Access
    API.

    Note that changing settings in QSslConfiguration is not enough to change the
    settings in the related SSL connection. You must call setSslConfiguration on
    a modified QSslConfiguration object to achieve that. The following example
    illustrates how to change the protocol to TLSv1_0 in a **QSslSocket**
    object:

    **QSslConfiguration**  config = sslSocket.sslConfiguration();
    config.setProtocol(QSsl::TlsV1_0);
    sslSocket.setSslConfiguration(config);

    **See also** **QSsl::SslProtocol** , **QSslCertificate** , **QSslCipher** ,
    **QSslKey** , **QSslSocket** , **QNetworkAccessManager** ,
    **QSslSocket::sslConfiguration** (), and **QSslSocket::setSslConfiguration**
    ().
    """

    class NextProtocolNegotiationStatus(enum.Enum):
        NextProtocolNegotiationNone: QSslConfiguration = ...
        NextProtocolNegotiationNegotiated: QSslConfiguration = ...
        NextProtocolNegotiationUnsupported: QSslConfiguration = ...

    NextProtocolHttp1_1: bytes = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#QSslConfiguration

        **QSslConfiguration::QSslConfiguration()**

        Constructs an empty SSL configuration. This configuration contains no
        valid settings and the state will be empty. **isNull** () will return
        true after this constructor is called.

        Once any setter methods are called, **isNull** () will return false.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#QSslConfiguration-1

        **QSslConfiguration::QSslConfiguration(const QSslConfiguration & other
        )**

        Copies the configuration and state of **other**. If **other** is null,
        this object will be null too.
        """
        ...

    def setMissingCertificateIsFatal(self, cannotRecover: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setMissingCertificateIsFat
        al

        **[since 6.0] void QSslConfiguration::setMissingCertificateIsFatal(bool
        cannotRecover )**

        If **cannotRecover** is true, and verification mode in use is
        **QSslSocket::VerifyPeer**  or **QSslSocket::AutoVerifyPeer**  (for a
        client-side socket), the missing peer's certificate would be treated as
        an unrecoverable error that cannot be ignored. A proper alert message
        will be sent to the peer before closing the connection.

        **Note:** Only available if Qt was configured and built with OpenSSL
        backend.

        This function was introduced in Qt 6.0.

        **See also** **QSslSocket::ignoreSslErrors** (),
        **QSslSocket::PeerVerifyMode** , and **missingCertificateIsFatal** ().
        """
        ...

    def missingCertificateIsFatal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#missingCertificateIsFatal

        **[since 6.0] bool QSslConfiguration::missingCertificateIsFatal()
        const**

        Returns true if errors with code **QSslError::NoPeerCertificate**
        cannot be ignored.

        **Note:** Always returns false for all TLS backends but OpenSSL.

        This function was introduced in Qt 6.0.

        **See also** **QSslSocket::ignoreSslErrors** () and
        **setMissingCertificateIsFatal** ().
        """
        ...

    def setHandshakeMustInterruptOnError(self, interrupt: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setHandshakeMustInterruptO
        nError

        **[since 6.0] void
        QSslConfiguration::setHandshakeMustInterruptOnError(bool interrupt )**

        If **interrupt** is true and the underlying backend supports this
        option, errors found during certificate verification are reported
        immediately by emitting **QSslSocket::handshakeInterruptedOnError** ().
        This allows to stop the unfinished handshake and send a proper alert
        message to a peer. No special action is required from the application in
        this case. **QSslSocket**  will close the connection after sending the
        alert message. If the application after inspecting the error wants to
        continue the handshake, it must call
        **QSslSocket::continueInterruptedHandshake** () from its slot function.
        The signal-slot connection must be direct.

        **Note:** When interrupting handshake is enabled, errors that would
        otherwise be reported by **QSslSocket::peerVerifyError** () are instead
        only reported by **QSslSocket::handshakeInterruptedOnError** ().

        **Note:** Even if the handshake was continued, these errors will be
        reported when emitting **QSslSocket::sslErrors** () signal (and thus
        must be ignored in the corresponding function slot).

        This function was introduced in Qt 6.0.

        **See also** **handshakeMustInterruptOnError** (),
        **QSslSocket::handshakeInterruptedOnError** (), and
        **QSslSocket::continueInterruptedHandshake** ().
        """
        ...

    def handshakeMustInterruptOnError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#handshakeMustInterruptOnEr
        ror

        **[since 6.0] bool QSslConfiguration::handshakeMustInterruptOnError()
        const**

        Returns true if a verification callback will emit
        **QSslSocket::handshakeInterruptedOnError** () early, before concluding
        the handshake.

        **Note:** This function always returns false for all backends but
        OpenSSL.

        This function was introduced in Qt 6.0.

        **See also** **setHandshakeMustInterruptOnError** (),
        **QSslSocket::handshakeInterruptedOnError** (), and
        **QSslSocket::continueInterruptedHandshake** ().
        """
        ...

    @typing.overload
    def addCaCertificates(
        self,
        path: str,
        format: QSsl.EncodingFormat = ...,
        syntax: QSslCertificate.PatternSyntax = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#addCaCertificates

        **[since 5.15] bool QSslConfiguration::addCaCertificates(const QString &
        path , QSsl::EncodingFormat format = QSsl::Pem,
        QSslCertificate::PatternSyntax syntax =
        QSslCertificate::PatternSyntax::FixedString)**

        Searches all files in the **path** for certificates encoded in the
        specified **format** and adds them to this socket's CA certificate
        database. **path** must be a file or a pattern matching one or more
        files, as specified by **syntax**. Returns `true` if one or more
        certificates are added to the socket's CA certificate database;
        otherwise returns `false`.

        The CA certificate database is used by the socket during the handshake
        phase to validate the peer's certificate.

        For more precise control, use **addCaCertificate** ().

        This function was introduced in Qt 5.15.

        **See also** **addCaCertificate** () and **QSslCertificate::fromPath**
        ().
        """
        ...

    @typing.overload
    def addCaCertificates(self, certificates: typing.Iterable[QSslCertificate]) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#addCaCertificates-1

        **[since 5.15] void QSslConfiguration::addCaCertificates(const
        QList<QSslCertificate> & certificates )**

        Adds **certificates** to this configuration's CA certificate database.
        The certificate database must be set prior to the SSL handshake. The CA
        certificate database is used by the socket during the handshake phase to
        validate the peer's certificate.

        **Note:** The default configuration uses the system CA certificate
        database. If that is not available (as is commonly the case on iOS), the
        default database is empty.

        This function was introduced in Qt 5.15.

        **See also** **caCertificates** (), **setCaCertificates** (), and
        **addCaCertificate** ().
        """
        ...

    def addCaCertificate(self, certificate: QSslCertificate) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#addCaCertificate

        **[since 5.15] void QSslConfiguration::addCaCertificate(const
        QSslCertificate & certificate )**

        Adds **certificate** to this configuration's CA certificate database.
        The certificate database must be set prior to the SSL handshake. The CA
        certificate database is used by the socket during the handshake phase to
        validate the peer's certificate.

        **Note:** The default configuration uses the system CA certificate
        database. If that is not available (as is commonly the case on iOS), the
        default database is empty.

        This function was introduced in Qt 5.15.

        **See also** **caCertificates** (), **setCaCertificates** (), and
        **addCaCertificates** ().
        """
        ...

    def ocspStaplingEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#ocspStaplingEnabled

        **[since 5.13] bool QSslConfiguration::ocspStaplingEnabled() const**

        Returns true if OCSP stapling was enabled by setOCSPStaplingEnabled(),
        otherwise false (which is the default value).

        This function was introduced in Qt 5.13.

        **See also** **setOcspStaplingEnabled** ().
        """
        ...

    def setOcspStaplingEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setOcspStaplingEnabled

        **[since 5.13] void QSslConfiguration::setOcspStaplingEnabled(bool
        enabled )**

        If **enabled** is true, client **QSslSocket**  will send a certificate
        status request to its peer when initiating a handshake. During the
        handshake **QSslSocket**  will verify the server's response. This value
        must be set before the handshake starts.

        This function was introduced in Qt 5.13.

        **See also** **ocspStaplingEnabled** ().
        """
        ...

    def setBackendConfiguration(
        self, backendConfiguration: typing.Dict[QtCore.QByteArray, typing.Any] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setBackendConfiguration

        **[since 5.11] void QSslConfiguration::setBackendConfiguration(const
        QMap<QByteArray, QVariant> & backendConfiguration = QMap<QByteArray,
        QVariant>())**

        Sets or clears the backend-specific configuration.

        Without a **backendConfiguration** parameter this function will clear
        the backend-specific configuration. More information about the supported
        options is available in the documentation of
        **setBackendConfigurationOption** ().

        This function was introduced in Qt 5.11.

        **See also** **backendConfiguration** () and
        **setBackendConfigurationOption** ().
        """
        ...

    def setBackendConfigurationOption(
        self, name: QtCore.QByteArray, value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setBackendConfigurationOpt
        ion

        **[since 5.11] void
        QSslConfiguration::setBackendConfigurationOption(const QByteArray & name
        , const QVariant & value )**

        Sets the option **name** in the backend-specific configuration to
        **value**.

        Options supported by the OpenSSL (>= 1.0.2) backend are available in the
        **supported configuration file commands**  documentation. The expected
        type for the **value** parameter is a **QByteArray**  for all options.
        The **examples**  show how to use some of the options.

        **Note:** The backend-specific configuration will be applied after the
        general configuration. Using the backend-specific configuration to set a
        general configuration option again will overwrite the general
        configuration option.

        This function was introduced in Qt 5.11.

        **See also** **backendConfiguration** () and **setBackendConfiguration**
        ().
        """
        ...

    def backendConfiguration(self) -> typing.Dict[QtCore.QByteArray, typing.Any]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#backendConfiguration

        **[since 5.11] QMap<QByteArray, QVariant>
        QSslConfiguration::backendConfiguration() const**

        Returns the backend-specific configuration.

        Only options set by **setBackendConfigurationOption** () or
        **setBackendConfiguration** () will be returned. The internal standard
        configuration of the backend is not reported.

        This function was introduced in Qt 5.11.

        **See also** **setBackendConfigurationOption** () and
        **setBackendConfiguration** ().
        """
        ...

    def setDiffieHellmanParameters(
        self, dhparams: "QSslDiffieHellmanParameters"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setDiffieHellmanParameters

        **[since 5.8] void QSslConfiguration::setDiffieHellmanParameters(const
        QSslDiffieHellmanParameters & dhparams )**

        Sets a custom set of Diffie-Hellman parameters to be used by this socket
        when functioning as a server to **dhparams**.

        If no Diffie-Hellman parameters have been set, the **QSslConfiguration**
        object defaults to using the 1024-bit MODP group from RFC 2409.

        This function was introduced in Qt 5.8.

        **See also** **diffieHellmanParameters** ().
        """
        ...

    def diffieHellmanParameters(self) -> "QSslDiffieHellmanParameters":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#diffieHellmanParameters

        **[since 5.8] QSslDiffieHellmanParameters
        QSslConfiguration::diffieHellmanParameters() const**

        Retrieves the current set of Diffie-Hellman parameters.

        If no Diffie-Hellman parameters have been set, the **QSslConfiguration**
        object defaults to using the 1024-bit MODP group from RFC 2409.

        This function was introduced in Qt 5.8.

        **See also** **setDiffieHellmanParameters** ().
        """
        ...

    def setPreSharedKeyIdentityHint(self, hint: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setPreSharedKeyIdentityHin
        t

        **[since 5.8] void QSslConfiguration::setPreSharedKeyIdentityHint(const
        QByteArray & hint )**

        Sets the identity hint for a preshared key authentication to **hint**.
        This will affect the next initiated handshake; calling this function on
        an already-encrypted socket will not affect the socket's identity hint.

        The identity hint is used in **QSslSocket::SslServerMode**  only!

        This function was introduced in Qt 5.8.

        **See also** **preSharedKeyIdentityHint** ().
        """
        ...

    def preSharedKeyIdentityHint(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#preSharedKeyIdentityHint

        **[since 5.8] QByteArray QSslConfiguration::preSharedKeyIdentityHint()
        const**

        Returns the identity hint.

        This function was introduced in Qt 5.8.

        **See also** **setPreSharedKeyIdentityHint** ().
        """
        ...

    def ephemeralServerKey(self) -> "QSslKey":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#ephemeralServerKey

        **[since 5.7] QSslKey QSslConfiguration::ephemeralServerKey() const**

        Returns the ephemeral server key used for cipher algorithms with forward
        secrecy, e.g. DHE-RSA-AES128-SHA.

        The ephemeral key is only available when running in client mode, i.e.
        **QSslSocket::SslClientMode** . When running in server mode or using a
        cipher algorithm without forward secrecy a null key is returned. The
        ephemeral server key will be set before emitting the encrypted() signal.

        This function was introduced in Qt 5.7.
        """
        ...

    @staticmethod
    def supportedEllipticCurves() -> typing.List["QSslEllipticCurve"]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#supportedEllipticCurves

        **[static, since 5.5] QList<QSslEllipticCurve>
        QSslConfiguration::supportedEllipticCurves()**

        Returns the list of elliptic curves supported by this system. This list
        is set by the system's SSL libraries and may vary from system to system.

        This function was introduced in Qt 5.5.

        **See also** **ellipticCurves** () and **setEllipticCurves** ().
        """
        ...

    def setEllipticCurves(self, curves: typing.Iterable["QSslEllipticCurve"]) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setEllipticCurves

        **[since 5.5] void QSslConfiguration::setEllipticCurves(const
        QList<QSslEllipticCurve> & curves )**

        Sets the list of elliptic curves to be used by this socket to **curves**
        , which must contain a subset of the curves in the list returned by
        **supportedEllipticCurves** ().

        Restricting the elliptic curves must be done before the handshake phase,
        where the session cipher is chosen.

        This function was introduced in Qt 5.5.

        **See also** **ellipticCurves** .
        """
        ...

    def ellipticCurves(self) -> typing.List["QSslEllipticCurve"]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#ellipticCurves

        **[since 5.5] QList<QSslEllipticCurve>
        QSslConfiguration::ellipticCurves() const**

        Returns this connection's current list of elliptic curves. This list is
        used during the handshake phase for choosing an elliptic curve (when
        using an elliptic curve cipher). The returned list of curves is ordered
        by descending preference (i.e., the first curve in the list is the most
        preferred one).

        By default, the handshake phase can choose any of the curves supported
        by this system's SSL libraries, which may vary from system to system.
        The list of curves supported by this system's SSL libraries is returned
        by QSslSocket::supportedEllipticCurves().

        You can restrict the list of curves used for choosing the session cipher
        for this socket by calling **setEllipticCurves** () with a subset of the
        supported ciphers. You can revert to using the entire set by calling
        **setEllipticCurves** () with the list returned by
        QSslSocket::supportedEllipticCurves().

        This function was introduced in Qt 5.5.

        **See also** **setEllipticCurves** .
        """
        ...

    @staticmethod
    def systemCaCertificates() -> typing.List[QSslCertificate]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#systemCaCertificates

        **[static, since 5.5] QList<QSslCertificate>
        QSslConfiguration::systemCaCertificates()**

        This function provides the CA certificate database provided by the
        operating system. The CA certificate database returned by this function
        is used to initialize the database returned by **caCertificates** () on
        the default **QSslConfiguration** .

        This function was introduced in Qt 5.5.

        **See also** **caCertificates** (), **setCaCertificates** (),
        **defaultConfiguration** (), **addCaCertificate** (), and
        **addCaCertificates** ().
        """
        ...

    @staticmethod
    def supportedCiphers() -> typing.List[QSslCipher]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#supportedCiphers

        **[static, since 5.5] QList<QSslCipher>
        QSslConfiguration::supportedCiphers()**

        Returns the list of cryptographic ciphers supported by this system. This
        list is set by the system's SSL libraries and may vary from system to
        system.

        This function was introduced in Qt 5.5.

        **See also** **ciphers** () and **setCiphers** ().
        """
        ...

    def sessionProtocol(self) -> QSsl.SslProtocol:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#sessionProtocol

        **[since 5.4] QSsl::SslProtocol QSslConfiguration::sessionProtocol()
        const**

        Returns the socket's SSL/TLS protocol or UnknownProtocol if the
        connection isn't encrypted. The socket's protocol for the session is set
        during the handshake phase.

        This function was introduced in Qt 5.4.

        **See also** **protocol** () and **setProtocol** ().
        """
        ...

    def nextProtocolNegotiationStatus(
        self,
    ) -> "QSslConfiguration.NextProtocolNegotiationStatus":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#nextProtocolNegotiationSta
        tus

        **[since 5.3] QSslConfiguration::NextProtocolNegotiationStatus
        QSslConfiguration::nextProtocolNegotiationStatus() const**

        This function returns the status of the Next Protocol Negotiation (NPN)
        or Application-Layer Protocol Negotiation (ALPN). If the feature has not
        been enabled through **setAllowedNextProtocols** (), this function
        returns **NextProtocolNegotiationNone** . The status will be set before
        emitting the encrypted() signal.

        This function was introduced in Qt 5.3.

        **See also** **setAllowedNextProtocols** (), **allowedNextProtocols**
        (), **nextNegotiatedProtocol** (), and
        **QSslConfiguration::NextProtocolNegotiationStatus** .
        """
        ...

    def nextNegotiatedProtocol(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#nextNegotiatedProtocol

        **[since 5.3] QByteArray QSslConfiguration::nextNegotiatedProtocol()
        const**

        This function returns the protocol negotiated with the server if the
        Next Protocol Negotiation (NPN) or Application-Layer Protocol
        Negotiation (ALPN) TLS extension was enabled. In order for the NPN/ALPN
        extension to be enabled, **setAllowedNextProtocols** () needs to be
        called explicitly before connecting to the server.

        If no protocol could be negotiated or the extension was not enabled,
        this function returns a **QByteArray**  which is null.

        This function was introduced in Qt 5.3.

        **See also** **setAllowedNextProtocols** () and
        **nextProtocolNegotiationStatus** ().
        """
        ...

    def allowedNextProtocols(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#allowedNextProtocols

        **[since 5.3] QList<QByteArray>
        QSslConfiguration::allowedNextProtocols() const**

        This function returns the allowed protocols to be negotiated with the
        server through the Next Protocol Negotiation (NPN) or Application-Layer
        Protocol Negotiation (ALPN) TLS extension, as set by
        **setAllowedNextProtocols** ().

        This function was introduced in Qt 5.3.

        **See also** **nextNegotiatedProtocol** (),
        **nextProtocolNegotiationStatus** (), **setAllowedNextProtocols** (),
        and **QSslConfiguration::NextProtocolHttp1_1** .
        """
        ...

    def setAllowedNextProtocols(
        self, protocols: typing.Iterable[QtCore.QByteArray]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setAllowedNextProtocols

        **[since 5.3] void QSslConfiguration::setAllowedNextProtocols(const
        QList<QByteArray> & protocols )**

        This function sets the allowed **protocols** to be negotiated with the
        server through the Next Protocol Negotiation (NPN) or Application-Layer
        Protocol Negotiation (ALPN) TLS extension; each element in **protocols**
        must define one allowed protocol. The function must be called explicitly
        before connecting to send the NPN/ALPN extension in the SSL handshake.
        Whether or not the negotiation succeeded can be queried through
        **nextProtocolNegotiationStatus** ().

        This function was introduced in Qt 5.3.

        **See also** **nextNegotiatedProtocol** (),
        **nextProtocolNegotiationStatus** (), **allowedNextProtocols** (), and
        **QSslConfiguration::NextProtocolHttp1_1** .
        """
        ...

    def sessionTicketLifeTimeHint(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#sessionTicketLifeTimeHint

        **[since 5.2] int QSslConfiguration::sessionTicketLifeTimeHint() const**

        If **QSsl::SslOptionDisableSessionPersistence**  was turned off, this
        function returns the session ticket life time hint sent by the server
        (which might be 0). If the server did not send a session ticket (e.g.
        when resuming a session or when the server does not support it) or
        **QSsl::SslOptionDisableSessionPersistence**  was not turned off, this
        function returns -1.

        This function was introduced in Qt 5.2.

        **See also** **sessionTicket** (),
        **QSsl::SslOptionDisableSessionPersistence** , **setSslOption** (), and
        **QSslSocket::newSessionTicketReceived** ().
        """
        ...

    def setSessionTicket(self, sessionTicket: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setSessionTicket

        **[since 5.2] void QSslConfiguration::setSessionTicket(const QByteArray
        & sessionTicket )**

        Sets the session ticket to be used in an SSL handshake.
        **QSsl::SslOptionDisableSessionPersistence**  must be turned off for
        this to work, and **sessionTicket** must be in ASN.1 format as returned
        by **sessionTicket** ().

        This function was introduced in Qt 5.2.

        **See also** **sessionTicket** (),
        **QSsl::SslOptionDisableSessionPersistence** , **setSslOption** (), and
        **QSslSocket::newSessionTicketReceived** ().
        """
        ...

    def sessionTicket(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#sessionTicket

        **[since 5.2] QByteArray QSslConfiguration::sessionTicket() const**

        If **QSsl::SslOptionDisableSessionPersistence**  was turned off, this
        function returns the session ticket used in the SSL handshake in ASN.1
        format, suitable to e.g. be persisted to disk. If no session ticket was
        used or **QSsl::SslOptionDisableSessionPersistence**  was not turned
        off, this function returns an empty **QByteArray** .

        **Note:** When persisting the session ticket to disk or similar, be
        careful not to expose the session to a potential attacker, as knowledge
        of the session allows for eavesdropping on data encrypted with the
        session parameters.

        This function was introduced in Qt 5.2.

        **See also** **setSessionTicket** (),
        **QSsl::SslOptionDisableSessionPersistence** , **setSslOption** (), and
        **QSslSocket::newSessionTicketReceived** ().
        """
        ...

    def setLocalCertificateChain(
        self, localChain: typing.Iterable[QSslCertificate]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setLocalCertificateChain

        **[since 5.1] void QSslConfiguration::setLocalCertificateChain(const
        QList<QSslCertificate> & localChain )**

        Sets the certificate chain to be presented to the peer during the SSL
        handshake to be **localChain**.

        Setting the certificate chain once the connection has been established
        has no effect.

        A certificate is the means of identification used in the SSL process.
        The local certificate is used by the remote end to verify the local
        user's identity against its list of Certification Authorities. In most
        cases, such as in HTTP web browsing, only servers identify to the
        clients, so the client does not send a certificate.

        Unlike **QSslConfiguration::setLocalCertificate** () this method allows
        you to specify any intermediate certificates required in order to
        validate your certificate. The first item in the list must be the leaf
        certificate.

        This function was introduced in Qt 5.1.

        **See also** **localCertificateChain** ().
        """
        ...

    def localCertificateChain(self) -> typing.List[QSslCertificate]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#localCertificateChain

        **[since 5.1] QList<QSslCertificate>
        QSslConfiguration::localCertificateChain() const**

        Returns the certificate chain to be presented to the peer during the SSL
        handshake process.

        This function was introduced in Qt 5.1.

        **See also** **setLocalCertificateChain** () and **localCertificate**
        ().
        """
        ...

    def swap(self, other: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#swap

        **[since 5.0] void QSslConfiguration::swap(QSslConfiguration & other )**

        Swaps this SSL configuration instance with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def testSslOption(self, option: QSsl.SslOption) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#testSslOption

        **bool QSslConfiguration::testSslOption(QSsl::SslOption option ) const**

        Returns `true` if the specified SSL compatibility **option** is enabled.

        **See also** **setSslOption** ().
        """
        ...

    def setSslOption(self, option: QSsl.SslOption, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setSslOption

        **void QSslConfiguration::setSslOption(QSsl::SslOption option , bool on
        )**

        Enables or disables an SSL compatibility **option**. If **on** is true,
        the **option** is enabled. If **on** is false, the **option** is
        disabled.

        **See also** **testSslOption** ().
        """
        ...

    @staticmethod
    def setDefaultConfiguration(configuration: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setDefaultConfiguration

        **[static] void QSslConfiguration::setDefaultConfiguration(const
        QSslConfiguration & configuration )**

        Sets the default SSL configuration to be used in new SSL connections to
        be **configuration**. Existing connections are not affected by this
        call.

        **See also** **supportedCiphers** () and **defaultConfiguration** ().
        """
        ...

    @staticmethod
    def defaultConfiguration() -> "QSslConfiguration":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#defaultConfiguration

        **[static] QSslConfiguration QSslConfiguration::defaultConfiguration()**

        Returns the default SSL configuration to be used in new SSL connections.

        The default SSL configuration consists of:

        * no local certificate and no private key
          * protocol
        **SecureProtocols**
          * the system's default CA certificate list
          *
        the cipher list equal to the list of the SSL libraries' supported SSL
        ciphers that are 128 bits or more

        **See also** **supportedCiphers** () and **setDefaultConfiguration** ().
        """
        ...

    def setCaCertificates(self, certificates: typing.Iterable[QSslCertificate]) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setCaCertificates

        **void QSslConfiguration::setCaCertificates(const QList<QSslCertificate>
        & certificates )**

        Sets this socket's CA certificate database to be **certificates**. The
        certificate database must be set prior to the SSL handshake. The CA
        certificate database is used by the socket during the handshake phase to
        validate the peer's certificate.

        **Note:** The default configuration uses the system CA certificate
        database. If that is not available (as is commonly the case on iOS), the
        default database is empty.

        **See also** **caCertificates** (), **addCaCertificates** (), and
        **addCaCertificate** ().
        """
        ...

    def caCertificates(self) -> typing.List[QSslCertificate]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#caCertificates

        **QList<QSslCertificate> QSslConfiguration::caCertificates() const**

        Returns this connection's CA certificate database. The CA certificate
        database is used by the socket during the handshake phase to validate
        the peer's certificate. It can be modified prior to the handshake with
        **setCaCertificates** (), or with **addCaCertificate** () and
        **addCaCertificates** ().

        **See also** **setCaCertificates** (), **addCaCertificate** (), and
        **addCaCertificates** ().
        """
        ...

    @typing.overload
    def setCiphers(self, ciphers: str) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setCiphers

        **void QSslConfiguration::setCiphers(const QList<QSslCipher> & ciphers
        )**

        Sets the cryptographic cipher suite for this socket to **ciphers** ,
        which must contain a subset of the ciphers in the list returned by
        **supportedCiphers** ().

        Restricting the cipher suite must be done before the handshake phase,
        where the session cipher is chosen.

        **Note:** This is not currently supported in the Schannel backend.

        **See also** **ciphers** () and **supportedCiphers** ().
        """
        ...

    @typing.overload
    def setCiphers(self, ciphers: typing.Iterable[QSslCipher]) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setCiphers-1

        **[since 6.0] void QSslConfiguration::setCiphers(const QString & ciphers
        )**

        Sets the cryptographic cipher suite for this configuration to
        **ciphers** , which is a colon-separated list of cipher suite names. The
        ciphers are listed in order of preference, starting with the most
        preferred cipher. For example:

        **QSslConfiguration**  tlsConfig = **QSslConfiguration**
        ::defaultConfiguration();
            tlsConfig.setCiphers(**QStringLiteral**
        ("DHE-RSA-AES256-SHA:DHE-DSS-AES256-SHA:AES256-SHA"));

        Each cipher name in **ciphers** must be the name of a cipher in the list
        returned by **supportedCiphers** (). Restricting the cipher suite must
        be done before the handshake phase, where the session cipher is chosen.

        **Note:** This is not currently supported in the Schannel backend.

        This function was introduced in Qt 6.0.

        **See also** **ciphers** ().
        """
        ...

    def ciphers(self) -> typing.List[QSslCipher]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#ciphers

        **QList<QSslCipher> QSslConfiguration::ciphers() const**

        Returns this connection's current cryptographic cipher suite. This list
        is used during the handshake phase for choosing a session cipher. The
        returned list of ciphers is ordered by descending preference. (i.e., the
        first cipher in the list is the most preferred cipher). The session
        cipher will be the first one in the list that is also supported by the
        peer.

        By default, the handshake phase can choose any of the ciphers supported
        by this system's SSL libraries, which may vary from system to system.
        The list of ciphers supported by this system's SSL libraries is returned
        by **supportedCiphers** (). You can restrict the list of ciphers used
        for choosing the session cipher for this socket by calling
        **setCiphers** () with a subset of the supported ciphers. You can revert
        to using the entire set by calling **setCiphers** () with the list
        returned by **supportedCiphers** ().

        **Note:** This is not currently supported in the Schannel backend.

        **See also** **setCiphers** () and **supportedCiphers** ().
        """
        ...

    def setPrivateKey(self, key: "QSslKey") -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setPrivateKey

        **void QSslConfiguration::setPrivateKey(const QSslKey & key )**

        Sets the connection's private **key**  to **key**. The private key and
        the local **certificate**  are used by clients and servers that must
        prove their identity to SSL peers.

        Both the key and the local certificate are required if you are creating
        an SSL server socket. If you are creating an SSL client socket, the key
        and local certificate are required if your client must identify itself
        to an SSL server.

        **See also** **privateKey** () and **setLocalCertificate** ().
        """
        ...

    def privateKey(self) -> "QSslKey":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#privateKey

        **QSslKey QSslConfiguration::privateKey() const**

        Returns the **SSL key**  assigned to this connection or a null key if
        none has been assigned yet.

        **See also** **setPrivateKey** () and **localCertificate** ().
        """
        ...

    def sessionCipher(self) -> QSslCipher:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#sessionCipher

        **QSslCipher QSslConfiguration::sessionCipher() const**

        Returns the socket's cryptographic **cipher** , or a null cipher if the
        connection isn't encrypted. The socket's cipher for the session is set
        during the handshake phase. The cipher is used to encrypt and decrypt
        data transmitted through the socket.

        The SSL infrastructure also provides functions for setting the ordered
        list of ciphers from which the handshake phase will eventually select
        the session cipher. This ordered list must be in place before the
        handshake phase begins.

        **See also** **ciphers** (), **setCiphers** (), and **supportedCiphers**
        ().
        """
        ...

    def peerCertificateChain(self) -> typing.List[QSslCertificate]:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#peerCertificateChain

        **QList<QSslCertificate> QSslConfiguration::peerCertificateChain()
        const**

        Returns the peer's chain of digital certificates, starting with the
        peer's immediate certificate and ending with the CA's certificate.

        Peer certificates are checked automatically during the handshake phase.
        This function is normally used to fetch certificates for display, or for
        performing connection diagnostics. Certificates contain information
        about the peer and the certificate issuers, including host name, issuer
        names, and issuer public keys.

        Because the peer certificate is set during the handshake phase, it is
        safe to access the peer certificate from a slot connected to the
        **QSslSocket::sslErrors** () signal, **QNetworkReply::sslErrors** ()
        signal, or the **QSslSocket::encrypted** () signal.

        If an empty list is returned, it can mean the SSL handshake failed, or
        it can mean the host you are connected to doesn't have a certificate, or
        it can mean there is no connection.

        If you want to get only the peer's immediate certificate, use
        **peerCertificate** ().

        **See also** **peerCertificate** (), **QSslSocket::sslErrors** (),
        **QSslSocket::ignoreSslErrors** (), **QNetworkReply::sslErrors** (), and
        **QNetworkReply::ignoreSslErrors** ().
        """
        ...

    def peerCertificate(self) -> QSslCertificate:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#peerCertificate

        **QSslCertificate QSslConfiguration::peerCertificate() const**

        Returns the peer's digital certificate (i.e., the immediate certificate
        of the host you are connected to), or a null certificate, if the peer
        has not assigned a certificate.

        The peer certificate is checked automatically during the handshake
        phase, so this function is normally used to fetch the certificate for
        display or for connection diagnostic purposes. It contains information
        about the peer, including its host name, the certificate issuer, and the
        peer's public key.

        Because the peer certificate is set during the handshake phase, it is
        safe to access the peer certificate from a slot connected to the
        **QSslSocket::sslErrors** () signal, **QNetworkReply::sslErrors** ()
        signal, or the **QSslSocket::encrypted** () signal.

        If a null certificate is returned, it can mean the SSL handshake failed,
        or it can mean the host you are connected to doesn't have a certificate,
        or it can mean there is no connection.

        If you want to check the peer's complete chain of certificates, use
        **peerCertificateChain** () to get them all at once.

        **See also** **peerCertificateChain** (), **QSslSocket::sslErrors** (),
        **QSslSocket::ignoreSslErrors** (), **QNetworkReply::sslErrors** (), and
        **QNetworkReply::ignoreSslErrors** ().
        """
        ...

    def setLocalCertificate(self, certificate: QSslCertificate) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setLocalCertificate

        **void QSslConfiguration::setLocalCertificate(const QSslCertificate &
        certificate )**

        Sets the certificate to be presented to the peer during SSL handshake to
        be **certificate**.

        Setting the certificate once the connection has been established has no
        effect.

        A certificate is the means of identification used in the SSL process.
        The local certificate is used by the remote end to verify the local
        user's identity against its list of Certification Authorities. In most
        cases, such as in HTTP web browsing, only servers identify to the
        clients, so the client does not send a certificate.

        **See also** **localCertificate** ().
        """
        ...

    def localCertificate(self) -> QSslCertificate:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#localCertificate

        **QSslCertificate QSslConfiguration::localCertificate() const**

        Returns the certificate to be presented to the peer during the SSL
        handshake process.

        **See also** **setLocalCertificate** ().
        """
        ...

    def setPeerVerifyDepth(self, depth: int) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setPeerVerifyDepth

        **void QSslConfiguration::setPeerVerifyDepth(int depth )**

        Sets the maximum number of certificates in the peer's certificate chain
        to be checked during the SSL handshake phase, to **depth**. Setting a
        depth of 0 means that no maximum depth is set, indicating that the whole
        certificate chain should be checked.

        The certificates are checked in issuing order, starting with the peer's
        own certificate, then its issuer's certificate, and so on.

        **See also** **peerVerifyDepth** () and **setPeerVerifyMode** ().
        """
        ...

    def peerVerifyDepth(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#peerVerifyDepth

        **int QSslConfiguration::peerVerifyDepth() const**

        Returns the maximum number of certificates in the peer's certificate
        chain to be checked during the SSL handshake phase, or 0 (the default)
        if no maximum depth has been set, indicating that the whole certificate
        chain should be checked.

        The certificates are checked in issuing order, starting with the peer's
        own certificate, then its issuer's certificate, and so on.

        **See also** **setPeerVerifyDepth** () and **peerVerifyMode** ().
        """
        ...

    def setPeerVerifyMode(self, mode: "QSslSocket.PeerVerifyMode") -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setPeerVerifyMode

        **void QSslConfiguration::setPeerVerifyMode(QSslSocket::PeerVerifyMode
        mode )**

        Sets the verify mode to **mode**. This mode decides whether
        **QSslSocket**  should request a certificate from the peer (i.e., the
        client requests a certificate from the server, or a server requesting a
        certificate from the client), and whether it should require that this
        certificate is valid.

        The default mode is AutoVerifyPeer, which tells **QSslSocket**  to use
        VerifyPeer for clients, QueryPeer for servers.

        **See also** **peerVerifyMode** ().
        """
        ...

    def peerVerifyMode(self) -> "QSslSocket.PeerVerifyMode":
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#peerVerifyMode

        **QSslSocket::PeerVerifyMode QSslConfiguration::peerVerifyMode() const**

        Returns the verify mode. This mode decides whether **QSslSocket**
        should request a certificate from the peer (i.e., the client requests a
        certificate from the server, or a server requesting a certificate from
        the client), and whether it should require that this certificate is
        valid.

        The default mode is AutoVerifyPeer, which tells **QSslSocket**  to use
        VerifyPeer for clients, QueryPeer for servers.

        **See also** **setPeerVerifyMode** ().
        """
        ...

    def setProtocol(self, protocol: QSsl.SslProtocol) -> None:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#setProtocol

        **void QSslConfiguration::setProtocol(QSsl::SslProtocol protocol )**

        Sets the protocol setting for this configuration to be **protocol**.

        Setting the protocol once the connection has already been established
        has no effect.

        **See also** **protocol** ().
        """
        ...

    def protocol(self) -> QSsl.SslProtocol:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#protocol

        **QSsl::SslProtocol QSslConfiguration::protocol() const**

        Returns the protocol setting for this SSL configuration.

        **See also** **setProtocol** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslconfiguration.html#isNull

        **bool QSslConfiguration::isNull() const**

        Returns `true` if this is a null **QSslConfiguration**  object.

        A **QSslConfiguration**  object is null if it has been default-
        constructed and no setter methods have been called.

        **See also** **setProtocol** (), **setLocalCertificate** (),
        **setPrivateKey** (), **setCiphers** (), and **setCaCertificates** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGTextureProvider(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsgtextureprovider.html

    **Detailed Description**

    The QSGTextureProvider lives primarily in the scene graph rendering thread.

    **See also** **Scene Graph - Two Texture Providers** .
    """

    def __init__(self) -> None:
        ...

    def texture(self) -> QSGTexture:
        """
        https://doc.qt.io/qt-6/qsgtextureprovider.html#texture

        **[pure virtual] QSGTexture *QSGTextureProvider::texture() const**

        Returns a pointer to the texture object.
        """
        ...

    @property
    def textureChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsgtextureprovider.html#textureChanged

        **[signal] void QSGTextureProvider::textureChanged()**

        This signal is emitted when the texture changes.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QAbstractListModel(QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qabstractlistmodel.html

    **Detailed Description**

    QAbstractListModel provides a standard interface for models that represent
    their data as a simple non-hierarchical sequence of items. It is not used
    directly, but must be subclassed.

    Since the model provides a more specialized interface than
    **QAbstractItemModel** , it is not suitable for use with tree views; you
    will need to subclass **QAbstractItemModel**  if you want to provide a model
    for that purpose. If you need to use a number of list models to manage data,
    it may be more appropriate to subclass **QAbstractTableModel**  instead.

    Simple models can be created by subclassing this class and implementing the
    minimum number of required functions. For example, we could implement a
    simple read-only **QStringList** -based model that provides a list of
    strings to a **QListView**  widget. In such a case, we only need to
    implement the **rowCount** () function to return the number of items in the
    list, and the **data** () function to retrieve items from the list.

    Since the model represents a one-dimensional structure, the **rowCount** ()
    function returns the total number of items in the model. The **columnCount**
    () function is implemented for interoperability with all kinds of views, but
    by default informs views that the model contains only one column.

    **Subclassing**

    When subclassing QAbstractListModel, you must provide implementations of the
    **rowCount** () and **data** () functions. Well behaved models also provide
    a **headerData** () implementation.

    If your model is used within QML and requires roles other than the default
    ones provided by the **roleNames** () function, you must override it.

    For editable list models, you must also provide an implementation of
    **setData** (), and implement the **flags** () function so that it returns a
    value containing **Qt::ItemIsEditable** .

    Note that QAbstractListModel provides a default implementation of
    **columnCount** () that informs views that there is only a single column of
    items in this model.

    Models that provide interfaces to resizable list-like data structures can
    provide implementations of **insertRows** () and **removeRows** (). When
    implementing these functions, it is important to call the appropriate
    functions so that all connected views are aware of any changes:

    * An **insertRows** () implementation must call **beginInsertRows** ()
    **before** inserting new rows into the data structure, and it must call
    **endInsertRows** () **immediately afterwards**.
      * A **removeRows** ()
    implementation must call **beginRemoveRows** () **before** the rows are
    removed from the data structure, and it must call **endRemoveRows** ()
    **immediately afterwards**.

    **Note:** Some general guidelines for subclassing models are available in
    the **Model Subclassing Reference** .

    **See also** **Model Classes** , **Model Subclassing Reference** ,
    **QAbstractItemView** , **QAbstractTableModel** , and **Item Views Puzzle
    Example** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractlistmodel.html#QAbstractListModel

        **QAbstractListModel::QAbstractListModel(QObject * parent = nullptr)**

        Constructs an abstract list model with the given **parent**.
        """
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractlistmodel.html#sibling

        **[override virtual] QModelIndex QAbstractListModel::sibling(int row ,
        int column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractItemModel::sibling(int row, int column, const
        QModelIndex &index) const** .
        """
        ...

    def parent(self) -> QObject:
        ...

    def flags(self, index: QModelIndex) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qabstractlistmodel.html#flags

        **[override virtual] Qt::ItemFlags QAbstractListModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def dropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractlistmodel.html#dropMimeData

        **[override virtual] bool QAbstractListModel::dropMimeData(const
        QMimeData * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).
        """
        ...

    def index(
        self, row: int, column: int = ..., parent: QModelIndex = ...
    ) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractlistmodel.html#index

        **[override virtual] QModelIndex QAbstractListModel::index(int row , int
        column = 0, const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .

        Returns the index of the data in **row** and **column** with **parent**.

        **See also** **parent** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QShortcutEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qshortcutevent.html

    **Detailed Description**

    Normally you do not need to use this class directly; **QShortcut**  provides
    a higher-level interface to handle shortcut keys.

    **See also** **QShortcut** .
    """

    def __init__(
        self,
        key: typing.Union["QKeySequence", "QKeySequence.StandardKey", str, int],
        id: int,
        ambiguous: bool = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qshortcutevent.html#QShortcutEvent-2

        **QShortcutEvent::QShortcutEvent(const QKeySequence & key , int id ,
        bool ambiguous = false)**

        Constructs a shortcut event for the given **key** press, associated with
        the **QShortcut**  ID **id**.

        **ambiguous** specifies whether there is more than one **QShortcut**
        for the same key sequence.
        """
        ...

    def clone(self) -> "QShortcutEvent":
        ...

    def shortcutId(self) -> int:
        """
        https://doc.qt.io/qt-6/qshortcutevent.html#shortcutId

        **int QShortcutEvent::shortcutId() const**

        Returns the ID of the **QShortcut**  object for which this event was
        generated.

        **See also** **QShortcut::id** ().
        """
        ...

    def key(self) -> "QKeySequence":
        """
        https://doc.qt.io/qt-6/qshortcutevent.html#key

        **const QKeySequence &QShortcutEvent::key() const**

        Returns the key sequence that triggered the event.
        """
        ...

    def isAmbiguous(self) -> bool:
        """
        https://doc.qt.io/qt-6/qshortcutevent.html#isAmbiguous

        **bool QShortcutEvent::isAmbiguous() const**

        Returns `true` if the key sequence that triggered the event is
        ambiguous.

        **See also** **QShortcut::activatedAmbiguously** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QModelIndex(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmodelindex.html

    **Detailed Description**

    This class is used as an index into item models derived from
    **QAbstractItemModel** . The index is used by item views, delegates, and
    selection models to locate an item in the model.

    New QModelIndex objects are created by the model using the
    **QAbstractItemModel::createIndex** () function. An **invalid** model index
    can be constructed with the QModelIndex constructor. Invalid indexes are
    often used as parent indexes when referring to top-level items in a model.

    Model indexes refer to items in models, and contain all the information
    required to specify their locations in those models. Each index is located
    in a given row and column, and may have a parent index; use **row** (),
    **column** (), and **parent** () to obtain this information. Each top-level
    item in a model is represented by a model index that does not have a parent
    index - in this case, **parent** () will return an invalid model index,
    equivalent to an index constructed with the zero argument form of the
    QModelIndex() constructor.

    To obtain a model index that refers to an existing item in a model, call
    **QAbstractItemModel::index** () with the required row and column values,
    and the model index of the parent. When referring to top-level items in a
    model, supply QModelIndex() as the parent index.

    The **model** () function returns the model that the index references as a
    **QAbstractItemModel** . The child() function is used to examine items held
    under the index in the model. The **sibling** () function allows you to
    traverse items in the model on the same level as the index.

    **Note:** Model indexes should be used immediately and then discarded. You
    should not rely on indexes to remain valid after calling model functions
    that change the structure of the model or delete items. If you need to keep
    a model index over time use a **QPersistentModelIndex** .

    **See also** **Model/View Programming** , **QPersistentModelIndex** , and
    **QAbstractItemModel** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#QModelIndex

        **QModelIndex::QModelIndex()**

        Creates a new empty model index. This type of model index is used to
        indicate that the position in the model is invalid.

        **See also** **isValid** () and **QAbstractItemModel** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QModelIndex") -> None:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#QModelIndex

        **QModelIndex::QModelIndex()**

        Creates a new empty model index. This type of model index is used to
        indicate that the position in the model is invalid.

        **See also** **isValid** () and **QAbstractItemModel** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPersistentModelIndex") -> None:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#QModelIndex

        **QModelIndex::QModelIndex()**

        Creates a new empty model index. This type of model index is used to
        indicate that the position in the model is invalid.

        **See also** **isValid** () and **QAbstractItemModel** .
        """
        ...

    def __hash__(self) -> int:
        ...

    def siblingAtRow(self, row: int) -> "QModelIndex":
        """
        https://doc.qt.io/qt-6/qmodelindex.html#siblingAtRow

        **[since 5.11] QModelIndex QModelIndex::siblingAtRow(int row ) const**

        Returns the sibling at **row** for the current column. If there is no
        sibling at this position, an invalid **QModelIndex**  is returned.

        This function was introduced in Qt 5.11.

        **See also** **sibling** () and **siblingAtColumn** ().
        """
        ...

    def siblingAtColumn(self, column: int) -> "QModelIndex":
        """
        https://doc.qt.io/qt-6/qmodelindex.html#siblingAtColumn

        **[since 5.11] QModelIndex QModelIndex::siblingAtColumn(int column )
        const**

        Returns the sibling at **column** for the current row. If there is no
        sibling at this position, an invalid **QModelIndex**  is returned.

        This function was introduced in Qt 5.11.

        **See also** **sibling** () and **siblingAtRow** ().
        """
        ...

    def sibling(self, arow: int, acolumn: int) -> "QModelIndex":
        """
        https://doc.qt.io/qt-6/qmodelindex.html#sibling

        **QModelIndex QModelIndex::sibling(int row , int column ) const**

        Returns the sibling at **row** and **column**. If there is no sibling at
        this position, an invalid **QModelIndex**  is returned.

        **See also** **parent** (), **siblingAtColumn** (), and **siblingAtRow**
        ().
        """
        ...

    def parent(self) -> "QModelIndex":
        """
        https://doc.qt.io/qt-6/qmodelindex.html#parent

        **QModelIndex QModelIndex::parent() const**

        Returns the parent of the model index, or **QModelIndex** () if it has
        no parent.

        **See also** **sibling** () and **model** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#isValid

        **bool QModelIndex::isValid() const**

        Returns `true` if this model index is valid; otherwise returns `false`.

        A valid index belongs to a model, and has non-negative row and column
        numbers.

        **See also** **model** (), **row** (), and **column** ().
        """
        ...

    def model(self) -> "QAbstractItemModel":
        """
        https://doc.qt.io/qt-6/qmodelindex.html#model

        **const QAbstractItemModel *QModelIndex::model() const**

        Returns a pointer to the model containing the item that this index
        refers to.

        A const pointer to the model is returned because calls to non-const
        functions of the model might invalidate the model index and possibly
        crash your application.
        """
        ...

    def internalId(self) -> int:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#internalId

        **quintptr QModelIndex::internalId() const**

        Returns a `quintptr` used by the model to associate the index with the
        internal data structure.

        **See also** **QAbstractItemModel::createIndex** ().
        """
        ...

    def internalPointer(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#internalPointer

        **void *QModelIndex::internalPointer() const**

        Returns a `void` `*` pointer used by the model to associate the index
        with the internal data structure.

        **See also** **QAbstractItemModel::createIndex** ().
        """
        ...

    def flags(self) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#flags

        **Qt::ItemFlags QModelIndex::flags() const**

        Returns the flags for the item referred to by the index.
        """
        ...

    def data(self, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#data

        **QVariant QModelIndex::data(int role = Qt::DisplayRole) const**

        Returns the data for the given **role** for the item referred to by the
        index.
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#column

        **int QModelIndex::column() const**

        Returns the column this model index refers to.
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qmodelindex.html#row

        **int QModelIndex::row() const**

        Returns the row this model index refers to.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerActionEditorInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html

    **Detailed Description**

    The QDesignerActionEditorInterface class is not intended to be instantiated
    directly. You can retrieve an interface to **Qt Designer** 's action editor
    using the **QDesignerFormEditorInterface::actionEditor** () function.

    You can control which actions that are available in the action editor's
    window using the **manageAction** () and **unmanageAction** () functions. An
    action that is managed by **Qt Designer** is available in the action editor
    while an unmanaged action is ignored.

    QDesignerActionEditorInterface also provides the **core** () function that
    you can use to retrieve a pointer to **Qt Designer** 's current
    **QDesignerFormEditorInterface**  object, and the **setFormWindow** ()
    function that enables you to change the currently selected form window.

    **See also** **QDesignerFormEditorInterface**  and
    **QDesignerFormWindowInterface** .
    """

    def __init__(
        self, parent: QtWidgets.QWidget, flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html#QDesignerActi
        onEditorInterface

        **QDesignerActionEditorInterface::QDesignerActionEditorInterface(QWidget
        * parent , Qt::WindowFlags flags = {})**

        Constructs an action editor interface with the given **parent** and the
        specified window **flags**.
        """
        ...

    def setFormWindow(self, formWindow: "QDesignerFormWindowInterface") -> None:
        """
        https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html#setFormWindow

        **[pure virtual slot] void QDesignerActionEditorInterface::setFormWindow
        (QDesignerFormWindowInterface * formWindow )**

        Sets the currently selected form window to **formWindow**.
        """
        ...

    def unmanageAction(self, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html#unmanageActio
        n

        **[pure virtual] void
        QDesignerActionEditorInterface::unmanageAction(QAction * action )**

        Instructs **Qt Designer** to ignore the specified **action**. An
        unmanaged action is not available in the action editor.

        **See also** **manageAction** ().
        """
        ...

    def manageAction(self, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html#manageAction

        **[pure virtual] void
        QDesignerActionEditorInterface::manageAction(QAction * action )**

        Instructs **Qt Designer** to manage the specified **action**. An action
        that is managed by **Qt Designer** is available in the action editor.

        **See also** **unmanageAction** ().
        """
        ...

    def core(self) -> "QDesignerFormEditorInterface":
        """
        https://doc.qt.io/qt-6/qdesigneractioneditorinterface.html#core

        **[virtual] QDesignerFormEditorInterface
        *QDesignerActionEditorInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QOpenGLPixelTransferOptions(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html

    **Detailed Description**
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#QOpenGLPixelTran
        sferOptions

        **QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions()**

        Constructs a new QOpenGLPixelTransferOptions instance with the default
        settings.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QOpenGLPixelTransferOptions") -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#QOpenGLPixelTran
        sferOptions

        **QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions()**

        Constructs a new QOpenGLPixelTransferOptions instance with the default
        settings.
        """
        ...

    def isSwapBytesEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#isSwapBytesEnabl
        ed

        **bool QOpenGLPixelTransferOptions::isSwapBytesEnabled() const**

        Returns `true` if the byte ordering for multibyte components is
        reversed.
        """
        ...

    def setSwapBytesEnabled(self, swapBytes: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSwapBytesEnab
        led

        **void QOpenGLPixelTransferOptions::setSwapBytesEnabled(bool swapBytes
        )**

        **swapBytes** specifies if the byte ordering for multibyte components is
        reversed. The default value is `false`. Corresponds to
        `GL_UNPACK_SWAP_BYTES`.

        **See also** **isSwapBytesEnabled** ().
        """
        ...

    def isLeastSignificantBitFirst(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#isLeastSignifica
        ntBitFirst

        **bool QOpenGLPixelTransferOptions::isLeastSignificantBitFirst() const**

        Returns `true` if bits within a byte are ordered from least to most
        significant.
        """
        ...

    def setLeastSignificantByteFirst(self, lsbFirst: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setLeastSignific
        antByteFirst

        **void QOpenGLPixelTransferOptions::setLeastSignificantByteFirst(bool
        lsbFirst )**

        **lsbFirst** specifies if bits within a byte are ordered from least to
        most significat. The default value is `false`, meaning that the first
        bit in each byte is the most significant one. This is significant for
        bitmap data only. Corresponds to `GL_UNPACK_LSB_FIRST`.
        """
        ...

    def rowLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#rowLength

        **int QOpenGLPixelTransferOptions::rowLength() const**

        Returns the currently set row length.

        **See also** **setRowLength** ().
        """
        ...

    def setRowLength(self, rowLength: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setRowLength

        **void QOpenGLPixelTransferOptions::setRowLength(int rowLength )**

        Sets the number of pixels in a row to **rowLength**. Corresponds to
        `GL_UNPACK_ROW_LENGTH`. The default value is 0.

        **See also** **rowLength** ().
        """
        ...

    def imageHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#imageHeight

        **int QOpenGLPixelTransferOptions::imageHeight() const**

        Returns the currently set image height.

        **See also** **setImageHeight** ().
        """
        ...

    def setImageHeight(self, imageHeight: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setImageHeight

        **void QOpenGLPixelTransferOptions::setImageHeight(int imageHeight )**

        Sets the image height for 3D textures to **imageHeight**. Corresponds to
        `GL_UNPACK_IMAGE_HEIGHT`. The default value is 0.

        **See also** **imageHeight** ().
        """
        ...

    def skipPixels(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipPixels

        **int QOpenGLPixelTransferOptions::skipPixels() const**

        Returns the number of pixels that are skipped.

        **See also** **setSkipPixels** ().
        """
        ...

    def setSkipPixels(self, skipPixels: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipPixels

        **void QOpenGLPixelTransferOptions::setSkipPixels(int skipPixels )**

        Sets the number of pixels that are skipped to **skipPixels**.
        Corresponds to `GL_UNPACK_SKIP_PIXELS`. Equivalent to incrementing the
        pointer passed to **QOpenGLTexture::setData** (). The default value is
        0.

        **See also** **skipPixels** ().
        """
        ...

    def skipRows(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipRows

        **int QOpenGLPixelTransferOptions::skipRows() const**

        Returns the number of rows that are skipped.

        **See also** **setSkipRows** ().
        """
        ...

    def setSkipRows(self, skipRows: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipRows

        **void QOpenGLPixelTransferOptions::setSkipRows(int skipRows )**

        Sets the number of rows that are skipped to **skipRows**. Corresponds to
        `GL_UNPACK_SKIP_ROWS`. Equivalent to incrementing the pointer passed to
        **QOpenGLTexture::setData** (). The default value is 0.

        **See also** **skipRows** ().
        """
        ...

    def skipImages(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipImages

        **int QOpenGLPixelTransferOptions::skipImages() const**

        Returns the number of images that are skipped.

        **See also** **setSkipImages** ().
        """
        ...

    def setSkipImages(self, skipImages: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipImages

        **void QOpenGLPixelTransferOptions::setSkipImages(int skipImages )**

        Sets the number of images that are skipped to **skipImages**.
        Corresponds to `GL_UNPACK_SKIP_IMAGES`. Equivalent to incrementing the
        pointer passed to **QOpenGLTexture::setData** (). The default value is
        0.

        **See also** **skipImages** ().
        """
        ...

    def alignment(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#alignment

        **int QOpenGLPixelTransferOptions::alignment() const**

        Returns the current alignment requirement for each pixel row.

        **See also** **setAlignment** ().
        """
        ...

    def setAlignment(self, alignment: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setAlignment

        **void QOpenGLPixelTransferOptions::setAlignment(int alignment )**

        Sets the **alignment** requirements for each pixel row. Corresponds to
        `GL_UNPACK_ALIGNMENT`. The default value is 4, as specified by OpenGL.

        **See also** **alignment** ().
        """
        ...

    def swap(self, other: "QOpenGLPixelTransferOptions") -> None:
        ...
